@@ -20,17 +20,23 @@ pub struct Options {
     pub find_untracked_repositories: FindRepository,
 }
 pub(crate) mod function {
-    use crate::repository::clean::{FindRepository, Options};
-    use crate::OutputFormat;
+    use std::{borrow::Cow, path::Path};
+
     use anyhow::bail;
-    use gix::bstr::BString;
-    use gix::bstr::ByteSlice;
-    use gix::dir::entry::{Kind, Status};
-    use gix::dir::walk::EmissionMode::CollapseDirectory;
-    use gix::dir::walk::ForDeletionMode::*;
-    use gix::dir::{walk, EntryRef};
-    use std::borrow::Cow;
-    use std::path::Path;
+    use gix::{
+        bstr::{BString, ByteSlice},
+        dir::{
+            entry::{Kind, Status},
+            walk,
+            walk::{EmissionMode::CollapseDirectory, ForDeletionMode::*},
+            EntryRef,
+        },
+    };
+
+    use crate::{
+        repository::clean::{FindRepository, Options},
+        OutputFormat,
+    };
 
     pub fn clean(
         repo: gix::Repository,
@@ -53,7 +59,7 @@ pub(crate) mod function {
         if format != OutputFormat::Human {
             bail!("JSON output isn't implemented yet");
         }
-        let Some(workdir) = repo.work_dir() else {
+        let Some(workdir) = repo.workdir() else {
             bail!("Need a worktree to clean, this is a bare repository");
         };
 
@@ -128,10 +134,10 @@ pub(crate) mod function {
             let pathspec_includes_entry = match pathspec.as_mut() {
                 None => entry
                     .pathspec_match
-                    .map_or(false, |m| m != gix::dir::entry::PathspecMatch::Excluded),
+                    .is_some_and(|m| m != gix::dir::entry::PathspecMatch::Excluded),
                 Some(pathspec) => pathspec
                     .pattern_matching_relative_path(entry.rela_path.as_bstr(), entry.disk_kind.map(|k| k.is_dir()))
-                    .map_or(false, |m| !m.is_excluded()),
+                    .is_some_and(|m| !m.is_excluded()),
             };
             pruned_entries += usize::from(!pathspec_includes_entry);
             if !pathspec_includes_entry && debug {
@@ -161,11 +167,16 @@ pub(crate) mod function {
             if entry.disk_kind.is_none() {
                 entry.disk_kind = workdir
                     .join(gix::path::from_bstr(entry.rela_path.as_bstr()))
-                    .metadata()
+                    .symlink_metadata()
                     .ok()
                     .map(|e| e.file_type().into());
             }
-            let mut disk_kind = entry.disk_kind.expect("present if not pruned");
+            let Some(mut disk_kind) = entry.disk_kind else {
+                if debug {
+                    writeln!(err, "DBG: ignoring unreadable entry at '{}' ", entry.rela_path).ok();
+                }
+                continue;
+            };
             if !keep {
                 if debug {
                     writeln!(err, "DBG: prune '{}' as -x or -p is missing", entry.rela_path).ok();
@@ -183,6 +194,12 @@ pub(crate) mod function {
             }
 
             match disk_kind {
+                Kind::Untrackable => {
+                    if debug {
+                        writeln!(err, "DBG: skipped untrackable entry at '{}'", entry.rela_path).ok();
+                    }
+                    continue;
+                }
                 Kind::File | Kind::Symlink => {}
                 Kind::Directory => {
                     if !directories {
@@ -202,7 +219,7 @@ pub(crate) mod function {
                         continue;
                     }
                 }
-            };
+            }
 
             let is_ignored = matches!(entry.status, gix::dir::entry::Status::Ignored(_));
             let entry_path = gix::path::from_bstr(entry.rela_path);
@@ -220,7 +237,7 @@ pub(crate) mod function {
                 out,
                 "{maybe}{suffix} {}{} {status}",
                 display_path.display(),
-                disk_kind.is_dir().then_some("/").unwrap_or_default(),
+                if disk_kind.is_dir() { "/" } else { Default::default() },
                 status = match entry.status {
                     Status::Ignored(kind) => {
                         Cow::Owned(format!(
@@ -254,6 +271,7 @@ pub(crate) mod function {
                     "WOULD remove"
                 },
                 suffix = match disk_kind {
+                    Kind::Untrackable => unreachable!("always skipped earlier"),
                     Kind::Directory if entry.property == Some(gix::dir::entry::Property::EmptyDirectory) => {
                         " empty"
                     }
