@@ -13,10 +13,7 @@ pub fn list(
     if format != OutputFormat::Human {
         bail!("Only human output format is supported at the moment");
     }
-    let repo = gix::open_opts(
-        repo.git_dir(),
-        repo.open_options().clone().lossy_config(false).cli_overrides(overrides),
-    )?;
+    let repo = gix::open_opts(repo.git_dir(), repo.open_options().clone().cli_overrides(overrides))?;
     let config = repo.config_snapshot();
     if let Some(frontmatter) = config.frontmatter() {
         for event in frontmatter {
@@ -32,7 +29,7 @@ pub fn list(
         }
 
         let meta = section.meta();
-        if last_meta.map_or(true, |last| last != meta) {
+        if last_meta != Some(meta) {
             write_meta(meta, &mut out)?;
         }
         last_meta = Some(meta);
@@ -41,9 +38,10 @@ pub fn list(
         for event in matter {
             event.write_to(&mut out)?;
         }
-        if it.peek().map_or(false, |(next_section, _)| {
-            next_section.header().name() != section.header().name()
-        }) {
+        if it
+            .peek()
+            .is_some_and(|(next_section, _)| next_section.header().name() != section.header().name())
+        {
             writeln!(&mut out)?;
         }
     }
@@ -83,7 +81,7 @@ impl Filter {
             }
             (None, _) => {}
             (Some(_), None) => return false,
-        };
+        }
         true
     }
 }
@@ -96,11 +94,15 @@ fn write_meta(meta: &gix::config::file::Metadata, out: &mut impl std::io::Write)
             .as_deref()
             .map_or_else(|| "memory".into(), |p| p.display().to_string()),
         meta.source,
-        (meta.level != 0)
-            .then(|| format!(", include level {}", meta.level))
-            .unwrap_or_default(),
-        (meta.trust != gix::sec::Trust::Full)
-            .then_some(", untrusted")
-            .unwrap_or_default()
+        if meta.level != 0 {
+            format!(", include level {}", meta.level)
+        } else {
+            Default::default()
+        },
+        if meta.trust != gix::sec::Trust::Full {
+            ", untrusted"
+        } else {
+            Default::default()
+        }
     )
 }
