@@ -23,9 +23,9 @@ pub(crate) mod function {
         io::{BufWriter, Write},
     };
 
-    use gix::index::entry::Stage;
     use gix::{
         bstr::{BStr, BString},
+        index::entry::Stage,
         worktree::IndexPersistedOrInMemory,
         Repository,
     };
@@ -184,7 +184,7 @@ pub(crate) mod function {
                                 .unwrap_or_default()
                         },
                     )
-                    .map_or(true, |m| m.is_excluded());
+                    .is_none_or(|m| m.is_excluded());
 
                 let entry_is_submodule = entry.mode.is_submodule();
                 if entry_is_excluded && (!entry_is_submodule || !recurse_submodules) {
@@ -198,7 +198,7 @@ pub(crate) mod function {
                         sms_by_path
                             .iter()
                             .find_map(|(path, sm)| (path == entry_path).then_some(sm))
-                            .filter(|sm| sm.git_dir_try_old_form().map_or(false, |dot_git| dot_git.exists()))
+                            .filter(|sm| sm.git_dir_try_old_form().is_ok_and(|dot_git| dot_git.exists()))
                     })
                 {
                     let sm_path = gix::path::to_unix_separators_on_windows(sm.path()?);
