@@ -1,9 +1,12 @@
-use anyhow::bail;
-use gix::bstr::{BStr, BString, ByteSlice};
-use gix::status::index_worktree::iter::Item;
-use gix_status::index_as_worktree::{Change, Conflict, EntryStatus};
 use std::path::Path;
 
+use anyhow::bail;
+use gix::{
+    bstr::{BStr, BString, ByteSlice},
+    status::{self, index_worktree},
+};
+use gix_status::index_as_worktree::{Change, Conflict, EntryStatus};
+
 use crate::OutputFormat;
 
 pub enum Submodules {
@@ -81,6 +84,7 @@ pub fn show(
                 copies: None,
                 percentage: Some(percentage),
                 limit: 0,
+                track_empty: false,
             });
             if opts.rewrites.is_some() {
                 if let Some(opts) = opts.dirwalk_options.as_mut() {
@@ -108,21 +112,49 @@ pub fn show(
             }
             None => gix::status::Submodule::AsConfigured { check_dirty: false },
         })
-        .into_index_worktree_iter(pathspecs)?;
+        .into_iter(pathspecs)?;
 
     for item in iter.by_ref() {
         let item = item?;
         match item {
-            Item::Modification {
+            status::Item::TreeIndex(change) => {
+                let (location, _, _, _) = change.fields();
+                let status = match change {
+                    gix::diff::index::Change::Addition { .. } => "A",
+                    gix::diff::index::Change::Deletion { .. } => "D",
+                    gix::diff::index::Change::Modification { .. } => "M",
+                    gix::diff::index::Change::Rewrite {
+                        ref source_location, ..
+                    } => {
+                        let source_location = gix::path::from_bstr(source_location.as_ref());
+                        let source_location = gix::path::relativize_with_prefix(&source_location, prefix);
+                        writeln!(
+                            out,
+                            "{status: >2}  {source_rela_path} → {dest_rela_path}",
+                            status = "R",
+                            source_rela_path = source_location.display(),
+                            dest_rela_path =
+                                gix::path::relativize_with_prefix(&gix::path::from_bstr(location), prefix).display(),
+                        )?;
+                        continue;
+                    }
+                };
+                writeln!(
+                    out,
+                    "{status: >2}  {rela_path}",
+                    rela_path = gix::path::relativize_with_prefix(&gix::path::from_bstr(location), prefix).display(),
+                )?;
+            }
+            status::Item::IndexWorktree(index_worktree::Item::Modification {
                 entry: _,
                 entry_index: _,
                 rela_path,
                 status,
-            } => print_index_entry_status(&mut out, prefix, rela_path.as_ref(), status)?,
-            Item::DirectoryContents {
+            }) => print_index_entry_status(&mut out, prefix, rela_path.as_ref(), status)?,
+            status::Item::IndexWorktree(index_worktree::Item::DirectoryContents {
                 entry,
                 collapsed_directory_status,
-            } => {
+            }) => {
                 if collapsed_directory_status.is_none() {
                     writeln!(
                         out,
@@ -138,12 +170,12 @@ pub fn show(
                     )?;
                 }
             }
-            Item::Rewrite {
+            status::Item::IndexWorktree(index_worktree::Item::Rewrite {
                 source,
                 dirwalk_entry,
                 copy: _, // TODO: how to visualize copies?
                 ..
-            } => {
+            }) => {
                 // TODO: handle multi-status characters, there can also be modifications at the same time as determined by their ID and potentially diffstats.
                 writeln!(
                     out,
@@ -174,9 +206,8 @@ pub fn show(
         writeln!(err, "{outcome:#?}", outcome = out.index_worktree).ok();
     }
 
-    writeln!(err, "\nhead -> index isn't implemented yet")?;
-    progress.init(Some(out.index.entries().len()), gix::progress::count("files"));
-    progress.set(out.index.entries().len());
+    progress.init(Some(out.worktree_index.entries().len()), gix::progress::count("files"));
+    progress.set(out.worktree_index.entries().len());
     progress.show_throughput(start);
     Ok(())
 }
@@ -221,7 +252,7 @@ fn change_to_char(change: &Change<(), gix::submodule::Status>) -> u8 {
     // Known status letters: https://github.com/git/git/blob/6807fcfedab84bc8cd0fbf721bc13c4e68cda9ae/diff.h#L613
     match change {
         Change::Removed => b'D',
-        Change::Type => b'T',
+        Change::Type { .. } => b'T',
         Change::SubmoduleModification(_) => b'M',
         Change::Modification {
             executable_bit_changed, ..
