@@ -1,4 +1,4 @@
-use std::{borrow::Cow, io};
+use std::{borrow::Cow, io, io::BufWriter};
 
 use anyhow::bail;
 use gix::Tree;
@@ -58,6 +58,9 @@ mod entries {
         }
 
         fn push_element(&mut self, name: &BStr) {
+            if name.is_empty() {
+                return;
+            }
             if !self.path.is_empty() {
                 self.path.push(b'/');
             }
@@ -66,6 +69,10 @@ mod entries {
     }
 
     impl gix::traverse::tree::Visit for Traverse<'_, '_> {
+        fn pop_back_tracked_path_and_set_current(&mut self) {
+            self.path = self.path_deque.pop_back().unwrap_or_default();
+        }
+
         fn pop_front_tracked_path_and_set_current(&mut self) {
             self.path = self.path_deque.pop_front().expect("every parent is set only once");
         }
@@ -91,12 +98,12 @@ mod entries {
         fn visit_nontree(&mut self, entry: &EntryRef<'_>) -> Action {
             let size = self
                 .repo
-                .and_then(|repo| repo.find_object(entry.oid).map(|o| o.data.len()).ok());
+                .and_then(|repo| repo.find_header(entry.oid).map(|h| h.size()).ok());
             if let Some(out) = &mut self.out {
                 format_entry(out, entry, self.path.as_bstr(), size).ok();
             }
             if let Some(size) = size {
-                self.stats.num_bytes += size as u64;
+                self.stats.num_bytes += size;
             }
 
             use gix::object::tree::EntryKind::*;
@@ -154,8 +161,9 @@ pub fn entries(
     let tree = treeish_to_tree(treeish, &repo)?;
 
     if recursive {
-        let mut delegate = entries::Traverse::new(extended.then_some(&repo), Some(&mut out));
-        tree.traverse().breadthfirst(&mut delegate)?;
+        let mut write = BufWriter::new(out);
+        let mut delegate = entries::Traverse::new(extended.then_some(&repo), Some(&mut write));
+        tree.traverse().depthfirst(&mut delegate)?;
     } else {
         for entry in tree.iter() {
             let entry = entry?;
@@ -163,9 +171,7 @@ pub fn entries(
                 &mut out,
                 &entry.inner,
                 entry.inner.filename,
-                extended
-                    .then(|| entry.id().object().map(|o| o.data.len()))
-                    .transpose()?,
+                extended.then(|| entry.id().header().map(|o| o.size())).transpose()?,
             )?;
         }
     }
@@ -182,12 +188,12 @@ fn format_entry(
     mut out: impl io::Write,
     entry: &gix::objs::tree::EntryRef<'_>,
     filename: &gix::bstr::BStr,
-    size: Option<usize>,
+    size: Option<u64>,
 ) -> std::io::Result<()> {
     use gix::objs::tree::EntryKind::*;
-    writeln!(
+    write!(
         out,
-        "{} {}{} {}",
+        "{} {}{} ",
         match entry.mode.kind() {
             Tree => "TREE",
             Blob => "BLOB",
@@ -196,7 +202,8 @@ fn format_entry(
             Commit => "SUBM",
         },
         entry.oid,
-        size.map_or_else(|| "".into(), |s| Cow::Owned(format!(" {s}"))),
-        filename
-    )
+        size.map_or_else(|| "".into(), |s| Cow::Owned(format!(" {s}")))
+    )?;
+    out.write_all(filename)?;
+    out.write_all(b"\n")
 }
