@@ -1,12 +1,12 @@
 #!/usr/bin/env bash
 set -eu -o pipefail
 
-mkdir basics;
+mkdir basics
 
 function baseline() {
   {
     echo "$1"
-    GIT_ATTR_NOSYSTEM=1 git -c core.attributesFile=$PWD/user.attributes check-attr -a "$1"
+    GIT_ATTR_NOSYSTEM=1 git -c core.attributesFile="$PWD/user.attributes" check-attr -a "$1"
     echo
   } >> baseline
 }
@@ -17,39 +17,40 @@ function baseline() {
 
   # based on https://github.com/git/git/blob/140b9478dad5d19543c1cb4fd293ccec228f1240/t/t0003-attributes.sh#L45
 	mkdir -p a/b/d a/c b
-	(
-		echo "[attr]notest !test"
-		echo "\" d \"	test=d"
-		echo " e	test=e"
-		echo " e\"	test=e"
-		echo "f	test=f"
-		echo "a/i test=a/i"
-		echo "onoff test -test"
-		echo "offon -test test"
-		echo "no notest"
-		echo "A/e/F test=A/e/F"
-		echo "\!escaped test-escaped"
-		echo "**/recursive test-double-star-slash"
-		echo "a**f test-double-star-no-slash"
-		echo "dir-slash/ never"
-		echo "dir/** always"
-	) > .gitattributes
-	(
-		echo "g test=a/g"
-		echo "b/g test=a/b/g"
-	) > a/.gitattributes
-	(
-		echo "h test=a/b/h"
-		echo "d/* test=a/b/d/*"
-		echo "d/yes notest"
-	) > a/b/.gitattributes
-	(
-		echo "global test=global"
-		echo "z/x/a global-no-wildcard-case-test"
-		echo "z/x/* global-wildcard-case-test"
-	) > user.attributes
+	{
+    echo '[attr]notest !test'
+    echo '" d "	test=d'
+    echo ' e	test=e'
+    echo ' e"	test=e'
+    echo 'f	test=f'
+    echo 'a/i test=a/i'
+    echo 'onoff test -test'
+    echo 'offon -test test'
+    echo 'no notest'
+    echo 'A/e/F test=A/e/F'
+    echo '\!escaped test-escaped'
+    echo '**/recursive test-double-star-slash'
+    echo 'a**f test-double-star-no-slash'
+    echo 'dir-slash/ never'
+    echo 'dir/** always'
+  } > .gitattributes
+  {
+    echo 'g test=a/g'
+    echo 'b/g test=a/b/g'
+  } > a/.gitattributes
+  {
+    echo 'h test=a/b/h'
+    echo 'd/* test=a/b/d/*'
+    echo 'd/yes notest'
+  } > a/b/.gitattributes
+  {
+    echo 'global test=global'
+    echo 'z/x/a global-no-wildcard-case-test'
+    echo 'z/x/* global-wildcard-case-test'
+	} > user.attributes
 
-	git add . && git commit -qm c1
+  git add .
+  git commit -qm c1
 
   baseline z/x/a
   baseline Z/x/a
@@ -67,7 +68,7 @@ function baseline() {
   baseline a/recursive
   baseline a/b/recursive
   baseline a/b/c/recursive
-  baseline "!escaped"
+  baseline '!escaped'
   baseline af
   baseline axf
   baseline a/b/d/no
@@ -77,7 +78,7 @@ function baseline() {
   baseline a/B/D/g
   baseline b/g
   baseline a/c/f
-  baseline "e\""
+  baseline 'e"'
   baseline a/i
   baseline A/b/h
   baseline A/B/D/NO
@@ -100,23 +101,23 @@ mkdir lookup-order
 (cd lookup-order
 
   function baseline_selected() {
-    local path=${1?first argument is the path to match}
+    local path="${1?first argument is the path to match}"
     shift
     {
       echo "$path"
-      git -c core.attributesFile=$PWD/user.attributes check-attr $@ -- "$path"
+      git -c core.attributesFile="$PWD/user.attributes" check-attr "$@" -- "$path"
       echo
     } >> baseline.selected
   }
 
   git init
-  cat <<EOF > user.attributes
+  cat <<'EOF' > user.attributes
 [attr]my-text text
 [attr]my-binary binary
 
 * location=user
 EOF
-  cat <<EOF > .gitattributes
+  cat <<'EOF' > .gitattributes
 [attr]b-cycle a-cycle my-text
 [attr]a-cycle b-cycle my-binary
 [attr]recursive recursively-assigned-attr
