@@ -1,6 +1,7 @@
-use gix_testtools::Result;
 use std::path::Path;
 
+use gix_testtools::Result;
+
 #[test]
 fn extract_interpreter() -> gix_testtools::Result {
     let root = gix_testtools::scripted_fixture_read_only("win_path_lookup.sh")?;
@@ -52,13 +53,13 @@ mod shebang {
                 "trimming works for tabs as well"
             );
             assert_eq!(
-                parse("#!\\bin\\sh"),
-                exe("\\bin\\sh"),
+                parse(r"#!\bin\sh"),
+                exe(r"\bin\sh"),
                 "backslashes are recognized as path separator"
             );
             assert_eq!(
                 parse("#!C:\\Program Files\\shell.exe\r\nsome stuff"),
-                exe("C:\\Program Files\\shell.exe"),
+                exe(r"C:\Program Files\shell.exe"),
                 "absolute windows paths are fine"
             );
             assert_eq!(
@@ -79,8 +80,9 @@ mod shebang {
 
             #[cfg(unix)]
             {
-                use bstr::ByteSlice;
                 use std::os::unix::ffi::OsStrExt;
+
+                use bstr::ByteSlice;
                 assert_eq!(
                     shebang::parse(b"#!/bin/sh   -x \xC3\x28\x41 -y  ".as_bstr()),
                     Some(shebang::Data {
@@ -192,8 +194,8 @@ mod context {
     #[test]
     fn glob_pathspecs_sets_env_only() {
         for (value, expected) in [
-            (false, "GIT_NOGLOB_PATHSPECS=\"1\""),
-            (true, "GIT_GLOB_PATHSPECS=\"1\""),
+            (false, r#"GIT_NOGLOB_PATHSPECS="1""#),
+            (true, r#"GIT_GLOB_PATHSPECS="1""#),
         ] {
             let ctx = Context {
                 glob_pathspecs: Some(value),
@@ -222,10 +224,13 @@ mod context {
 }
 
 mod prepare {
-    #[cfg(windows)]
-    const SH: &str = "sh";
-    #[cfg(not(windows))]
-    const SH: &str = "/bin/sh";
+    use once_cell::sync::Lazy;
+
+    static SH: Lazy<&'static str> = Lazy::new(|| {
+        gix_path::env::shell()
+            .to_str()
+            .expect("`prepare` tests must be run where 'sh' path is valid Unicode")
+    });
 
     fn quoted(input: &[&str]) -> String {
         input.iter().map(|s| format!("\"{s}\"")).collect::<Vec<_>>().join(" ")
@@ -246,7 +251,8 @@ mod prepare {
     #[test]
     fn multiple_arguments_in_one_line_with_auto_split() {
         let cmd = std::process::Command::from(
-            gix_command::prepare("echo first second third").with_shell_allow_argument_splitting(),
+            gix_command::prepare("echo first second third")
+                .command_may_be_shell_script_allow_manual_argument_splitting(),
         );
         assert_eq!(
             format!("{cmd:?}"),
@@ -267,27 +273,51 @@ mod prepare {
 
     #[test]
     fn single_and_multiple_arguments_as_part_of_command_with_shell() {
-        let cmd = std::process::Command::from(gix_command::prepare("ls first second third").with_shell());
+        let cmd =
+            std::process::Command::from(gix_command::prepare("ls first second third").command_may_be_shell_script());
         assert_eq!(
             format!("{cmd:?}"),
             if cfg!(windows) {
                 quoted(&["ls", "first", "second", "third"])
             } else {
-                quoted(&[SH, "-c", "ls first second third", "--"])
+                quoted(&[*SH, "-c", "ls first second third", "--"])
             },
             "with shell, this works as it performs word splitting"
         );
     }
 
+    #[test]
+    fn single_and_multiple_arguments_as_part_of_command_with_given_shell() {
+        let cmd = std::process::Command::from(
+            gix_command::prepare("ls first second third")
+                .command_may_be_shell_script()
+                .with_shell_program("/somepath/to/bash"),
+        );
+        assert_eq!(
+            format!("{cmd:?}"),
+            if cfg!(windows) {
+                quoted(&["ls", "first", "second", "third"])
+            } else {
+                quoted(&["/somepath/to/bash", "-c", "ls first second third", "--"])
+            },
+            "with shell, this works as it performs word splitting on Windows, but on linux (or without splitting) it uses the given shell"
+        );
+    }
+
     #[test]
     fn single_and_complex_arguments_as_part_of_command_with_shell() {
-        let cmd = std::process::Command::from(gix_command::prepare("ls --foo \"a b\"").arg("additional").with_shell());
+        let cmd = std::process::Command::from(
+            gix_command::prepare(r#"ls --foo "a b""#)
+                .arg("additional")
+                .command_may_be_shell_script(),
+        );
         assert_eq!(
             format!("{cmd:?}"),
             if cfg!(windows) {
                 quoted(&["ls", "--foo", "a b", "additional"])
             } else {
-                format!(r#""{SH}" "-c" "ls --foo \"a b\" \"$@\"" "--" "additional""#)
+                let sh = *SH;
+                format!(r#""{sh}" "-c" "ls --foo \"a b\" \"$@\"" "--" "additional""#)
             },
             "with shell, this works as it performs word splitting"
         );
@@ -295,8 +325,9 @@ mod prepare {
 
     #[test]
     fn single_and_complex_arguments_with_auto_split() {
-        let cmd =
-            std::process::Command::from(gix_command::prepare("ls --foo=\"a b\"").with_shell_allow_argument_splitting());
+        let cmd = std::process::Command::from(
+            gix_command::prepare(r#"ls --foo="a b""#).command_may_be_shell_script_allow_manual_argument_splitting(),
+        );
         assert_eq!(
             format!("{cmd:?}"),
             format!(r#""ls" "--foo=a b""#),
@@ -305,48 +336,131 @@ mod prepare {
     }
 
     #[test]
-    fn single_and_complex_arguments_will_not_auto_split_on_special_characters() {
-        let cmd =
-            std::process::Command::from(gix_command::prepare("ls --foo=~/path").with_shell_allow_argument_splitting());
+    fn single_and_complex_arguments_without_auto_split() {
+        let cmd = std::process::Command::from(
+            gix_command::prepare(r#"ls --foo="a b""#).command_may_be_shell_script_disallow_manual_argument_splitting(),
+        );
+        assert_eq!(format!("{cmd:?}"), quoted(&[*SH, "-c", r#"ls --foo=\"a b\""#, "--"]));
+    }
+
+    #[test]
+    fn single_and_simple_arguments_without_auto_split_with_shell() {
+        let cmd = std::process::Command::from(
+            gix_command::prepare("ls")
+                .arg("--foo=a b")
+                .command_may_be_shell_script_disallow_manual_argument_splitting()
+                .with_shell(),
+        );
         assert_eq!(
             format!("{cmd:?}"),
-            format!(r#""{SH}" "-c" "ls --foo=~/path" "--""#),
+            quoted(&[*SH, "-c", r#"ls \"$@\""#, "--", "--foo=a b"])
+        );
+    }
+
+    #[test]
+    fn quoted_command_without_argument_splitting() {
+        let cmd = std::process::Command::from(
+            gix_command::prepare("ls")
+                .arg("--foo=a b")
+                .command_may_be_shell_script_disallow_manual_argument_splitting()
+                .with_shell()
+                .with_quoted_command(),
+        );
+        assert_eq!(
+            format!("{cmd:?}"),
+            quoted(&[*SH, "-c", r#"\'ls\' \"$@\""#, "--", "--foo=a b"]),
+            "looks strange thanks to debug printing, but is the right amount of quotes actually"
+        );
+    }
+
+    #[test]
+    fn quoted_windows_command_without_argument_splitting() {
+        let cmd = std::process::Command::from(
+            gix_command::prepare(r"C:\Users\O'Shaughnessy\with space.exe")
+                .arg("--foo='a b'")
+                .command_may_be_shell_script_disallow_manual_argument_splitting()
+                .with_shell()
+                .with_quoted_command(),
+        );
+        assert_eq!(
+            format!("{cmd:?}"),
+            quoted(&[
+                *SH,
+                "-c",
+                r#"\'C:\\Users\\O\'\\\'\'Shaughnessy\\with space.exe\' \"$@\""#,
+                "--",
+                r"--foo=\'a b\'"
+            ]),
+            "again, a lot of extra backslashes, but it's correct outside of the debug formatting"
+        );
+    }
+
+    #[test]
+    fn single_and_complex_arguments_will_not_auto_split_on_special_characters() {
+        let cmd = std::process::Command::from(
+            gix_command::prepare("ls --foo=~/path").command_may_be_shell_script_allow_manual_argument_splitting(),
+        );
+        let sh = *SH;
+        assert_eq!(
+            format!("{cmd:?}"),
+            format!(r#""{sh}" "-c" "ls --foo=~/path" "--""#),
             "splitting can also handle quotes"
         );
     }
 
     #[test]
     fn tilde_path_and_multiple_arguments_as_part_of_command_with_shell() {
-        let cmd = std::process::Command::from(gix_command::prepare("~/bin/exe --foo \"a b\"").with_shell());
+        let cmd =
+            std::process::Command::from(gix_command::prepare(r#"~/bin/exe --foo "a b""#).command_may_be_shell_script());
+        let sh = *SH;
         assert_eq!(
             format!("{cmd:?}"),
-            format!(r#""{SH}" "-c" "~/bin/exe --foo \"a b\"" "--""#),
+            format!(r#""{sh}" "-c" "~/bin/exe --foo \"a b\"" "--""#),
             "this always needs a shell as we need tilde expansion"
         );
     }
 
     #[test]
     fn script_with_dollar_at() {
-        let cmd = std::process::Command::from(gix_command::prepare("echo \"$@\" >&2").with_shell().arg("store"));
+        let cmd = std::process::Command::from(
+            gix_command::prepare(r#"echo "$@" >&2"#)
+                .command_may_be_shell_script()
+                .arg("store"),
+        );
+        let sh = *SH;
         assert_eq!(
             format!("{cmd:?}"),
-            format!(r#""{SH}" "-c" "echo \"$@\" >&2" "--" "store""#),
+            format!(r#""{sh}" "-c" "echo \"$@\" >&2" "--" "store""#),
             "this is how credential helpers have to work as for some reason they don't get '$@' added in Git.\
             We deal with it by not doubling the '$@' argument, which seems more flexible."
         );
     }
+
+    #[test]
+    fn script_with_dollar_at_has_no_quoting() {
+        let cmd = std::process::Command::from(
+            gix_command::prepare(r#"echo "$@" >&2"#)
+                .command_may_be_shell_script()
+                .with_quoted_command()
+                .arg("store"),
+        );
+        let sh = *SH;
+        assert_eq!(
+            format!("{cmd:?}"),
+            format!(r#""{sh}" "-c" "echo \"$@\" >&2" "--" "store""#)
+        );
+    }
 }
 
 mod spawn {
     use bstr::ByteSlice;
 
     #[test]
-    #[cfg(unix)]
     fn environment_variables_are_passed_one_by_one() -> crate::Result {
         let out = gix_command::prepare("echo $FIRST $SECOND")
             .env("FIRST", "first")
             .env("SECOND", "second")
-            .with_shell()
+            .command_may_be_shell_script()
             .spawn()?
             .wait_with_output()?;
         assert_eq!(out.stdout.as_bstr(), "first second\n");
@@ -354,15 +468,17 @@ mod spawn {
     }
 
     #[test]
-    #[cfg(unix)]
     fn disallow_shell() -> crate::Result {
         let out = gix_command::prepare("PATH= echo hi")
-            .with_shell()
+            .command_may_be_shell_script_disallow_manual_argument_splitting()
             .spawn()?
             .wait_with_output()?;
         assert_eq!(out.stdout.as_bstr(), "hi\n");
 
-        let mut cmd: std::process::Command = gix_command::prepare("echo hi").with_shell().without_shell().into();
+        let mut cmd: std::process::Command = gix_command::prepare("echo hi")
+            .command_may_be_shell_script()
+            .without_shell()
+            .into();
         assert!(
             cmd.env_remove("PATH").spawn().is_err(),
             "no command named 'echo hi' exists"
@@ -372,9 +488,13 @@ mod spawn {
 
     #[test]
     fn script_with_dollar_at() -> crate::Result {
-        let out = std::process::Command::from(gix_command::prepare("echo \"$@\"").with_shell().arg("arg"))
-            .spawn()?
-            .wait_with_output()?;
+        let out = std::process::Command::from(
+            gix_command::prepare(r#"echo "$@""#)
+                .command_may_be_shell_script()
+                .arg("arg"),
+        )
+        .spawn()?
+        .wait_with_output()?;
         assert_eq!(
             out.stdout.to_str_lossy().trim(),
             "arg",
@@ -395,7 +515,7 @@ mod spawn {
     #[cfg(unix)]
     #[test]
     fn direct_command_with_absolute_command_path() -> crate::Result {
-        assert!(gix_command::prepare("/bin/ls").spawn()?.wait()?.success());
+        assert!(gix_command::prepare("/usr/bin/env").spawn()?.wait()?.success());
         Ok(())
     }
 
@@ -405,7 +525,7 @@ mod spawn {
         #[test]
         fn command_in_path_with_args() -> crate::Result {
             assert!(gix_command::prepare(if cfg!(unix) { "ls -l" } else { "dir.exe -a" })
-                .with_shell()
+                .command_may_be_shell_script()
                 .spawn()?
                 .wait()?
                 .success());
@@ -414,14 +534,18 @@ mod spawn {
 
         #[test]
         fn sh_shell_specific_script_code() -> crate::Result {
-            assert!(gix_command::prepare(":;:;:").with_shell().spawn()?.wait()?.success());
+            assert!(gix_command::prepare(":;:;:")
+                .command_may_be_shell_script()
+                .spawn()?
+                .wait()?
+                .success());
             Ok(())
         }
 
         #[test]
         fn sh_shell_specific_script_code_with_single_extra_arg() -> crate::Result {
             let out = gix_command::prepare("printf")
-                .with_shell()
+                .command_may_be_shell_script()
                 .arg("1")
                 .spawn()?
                 .wait_with_output()?;
@@ -433,7 +557,7 @@ mod spawn {
         #[test]
         fn sh_shell_specific_script_code_with_multiple_extra_args() -> crate::Result {
             let out = gix_command::prepare("printf")
-                .with_shell()
+                .command_may_be_shell_script()
                 .arg("%s")
                 .arg("arg")
                 .spawn()?
