@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 set -eu -o pipefail
 
-function tick () {
+function tick() {
   if test -z "${tick+set}"
   then
     tick=1112911993
@@ -13,9 +13,25 @@ function tick () {
   export GIT_COMMITTER_DATE GIT_AUTHOR_DATE
 }
 
-tick
-function commit() {
-  local message=${1:?first argument is the commit message}
+function force_tag() {
+  local name head_oid common_dir
+  name=${1:?argument the tag name}
+
+  # This should only be needed with 32-bit `git`, so fail otherwise.
+  word_size="$(
+    git --version --build-options |
+      awk '$1 == "sizeof-size_t:" { print $2 }'
+  )"
+  ((word_size == 4))
+
+  # Manually create the tag.
+  head_oid="$(git rev-parse HEAD)"
+  common_dir="$(git rev-parse --git-common-dir)"
+  (set -o noclobber; echo "$head_oid" > "$common_dir/refs/tags/$name")
+}
+
+function tagged_commit() {
+  local message=${1:?first argument is the commit message and tag name}
   local date=${2:-}
   local file="$message.t"
   echo "$1" > "$file"
@@ -26,9 +42,11 @@ function commit() {
     tick
   fi
   git commit -m "$message"
-  git tag "$message"
+  git tag -- "$message" || force_tag "$message"
 }
 
+tick
+
 # adapted from git/t/t5318 'lower layers have overflow chunk'
 UNIX_EPOCH_ZERO="@0 +0000"
 FUTURE_DATE="@4147483646 +0000"
@@ -36,12 +54,12 @@ FUTURE_DATE="@4147483646 +0000"
 git init
 git config commitGraph.generationVersion 2
 
-commit future-1 "$FUTURE_DATE"
-commit old-1 "$UNIX_EPOCH_ZERO"
+tagged_commit future-1 "$FUTURE_DATE"
+tagged_commit old-1 "$UNIX_EPOCH_ZERO"
 git commit-graph write --reachable
-commit future-2 "$FUTURE_DATE"
-commit old-2 "$UNIX_EPOCH_ZERO"
+tagged_commit future-2 "$FUTURE_DATE"
+tagged_commit old-2 "$UNIX_EPOCH_ZERO"
 git commit-graph write --reachable --split=no-merge
-commit extra
+tagged_commit extra
 # this makes sure it's actually in chain format.
 git commit-graph write --reachable --split=no-merge
