@@ -1,7 +1,7 @@
+use std::{alloc, time::Instant};
+
 use bytesize::ByteSize;
 use cap::Cap;
-use std::alloc;
-use std::time::Instant;
 
 #[global_allocator]
 static ALLOCATOR: Cap<alloc::System> = Cap::new(alloc::System, usize::MAX);
