@@ -3,23 +3,6 @@ use gix_date::Time;
 mod baseline;
 mod format;
 mod parse;
-mod init {
-    use gix_date::Time;
-
-    #[test]
-    fn utc_local_handles_signs_correctly() {
-        for time in [
-            Time::now_local_or_utc(),
-            Time::now_local().unwrap_or_else(Time::now_utc),
-        ] {
-            assert_eq!(
-                time.sign,
-                time.offset.into(),
-                "the sign matches the sign of the date offset"
-            );
-        }
-    }
-}
 
 #[test]
 fn is_set() {
@@ -33,15 +16,13 @@ fn is_set() {
 
 mod write_to {
     use bstr::ByteSlice;
-    use gix_date::time::Sign;
-    use gix_date::{SecondsSinceUnixEpoch, Time};
+    use gix_date::{parse::TimeBuf, SecondsSinceUnixEpoch, Time};
 
     #[test]
     fn invalid() {
         let time = Time {
             seconds: 0,
             offset: (100 * 60 * 60) + 30 * 60,
-            sign: Sign::Plus,
         };
         let err = time.write_to(&mut Vec::new()).unwrap_err();
         assert_eq!(err.to_string(), "Cannot represent offsets larger than +-9900");
@@ -54,23 +35,20 @@ mod write_to {
                 Time {
                     seconds: SecondsSinceUnixEpoch::MAX,
                     offset: 0,
-                    sign: Sign::Minus,
                 },
-                "9223372036854775807 -0000",
+                "9223372036854775807 +0000",
             ),
             (
                 Time {
                     seconds: SecondsSinceUnixEpoch::MIN,
                     offset: 0,
-                    sign: Sign::Minus,
                 },
-                "-9223372036854775808 -0000",
+                "-9223372036854775808 +0000",
             ),
             (
                 Time {
                     seconds: 500,
                     offset: 9000,
-                    sign: Sign::Plus,
                 },
                 "500 +0230",
             ),
@@ -78,23 +56,14 @@ mod write_to {
                 Time {
                     seconds: 189009009,
                     offset: -36000,
-                    sign: Sign::Minus,
                 },
                 "189009009 -1000",
             ),
-            (
-                Time {
-                    seconds: 0,
-                    offset: 0,
-                    sign: Sign::Minus,
-                },
-                "0 -0000",
-            ),
+            (Time { seconds: 0, offset: 0 }, "0 +0000"),
             (
                 Time {
                     seconds: 0,
                     offset: -24 * 60 * 60,
-                    sign: Sign::Minus,
                 },
                 "0 -2400",
             ),
@@ -102,7 +71,6 @@ mod write_to {
                 Time {
                     seconds: 0,
                     offset: 24 * 60 * 60,
-                    sign: Sign::Plus,
                 },
                 "0 +2400",
             ),
@@ -110,7 +78,6 @@ mod write_to {
                 Time {
                     seconds: 0,
                     offset: (25 * 60 * 60) + 30 * 60,
-                    sign: Sign::Plus,
                 },
                 "0 +2530",
             ),
@@ -118,7 +85,6 @@ mod write_to {
                 Time {
                     seconds: 0,
                     offset: (-25 * 60 * 60) - 30 * 60,
-                    sign: Sign::Minus,
                 },
                 "0 -2530",
             ),
@@ -126,7 +92,6 @@ mod write_to {
                 Time {
                     seconds: 0,
                     offset: (99 * 60 * 60) + 59 * 60,
-                    sign: Sign::Plus,
                 },
                 "0 +9959",
             ),
@@ -141,4 +106,17 @@ mod write_to {
         }
         Ok(())
     }
+
+    #[test]
+    fn max() -> gix_testtools::Result {
+        let mut buf = TimeBuf::default();
+        Time::MAX.write_to(&mut buf)?;
+        assert_eq!(Time::MAX.size(), 25, "The largest possible serialized size");
+
+        let expected = "9223372036854775807 +9959";
+        assert_eq!(buf.as_str(), expected);
+        assert_eq!(buf.as_str().len(), Time::MAX.size());
+        assert_eq!(Time::MAX.to_str(&mut buf), expected);
+        Ok(())
+    }
 }
