@@ -1,8 +1,3 @@
-use crate::{
-    hex_to_id,
-    rewrites::{Change, NULL_ID},
-};
-use gix_diff::tree::visit::Relation;
 use gix_diff::{
     blob::DiffLineStats,
     rewrites,
@@ -13,12 +8,17 @@ use gix_diff::{
         },
         Copies, CopySource,
     },
-    tree::visit::Action,
+    tree::visit::{Action, Relation},
     Rewrites,
 };
 use gix_object::tree::EntryKind;
 use pretty_assertions::assert_eq;
 
+use crate::{
+    hex_to_id,
+    rewrites::{Change, NULL_ID},
+};
+
 #[test]
 fn rename_by_id() -> crate::Result {
     // Limits are only applied when doing rewrite-checks
@@ -27,6 +27,7 @@ fn rename_by_id() -> crate::Result {
             copies: None,
             percentage: None,
             limit,
+            track_empty: false,
         };
         let mut track = util::new_tracker(rewrites);
         assert!(
@@ -80,6 +81,7 @@ fn copy_by_similarity_reports_limit_if_encountered() -> crate::Result {
         }),
         percentage: None,
         limit: 1,
+        track_empty: false,
     };
     let mut track = util::new_tracker(rewrites);
     let odb = util::add_retained_blobs(
@@ -90,7 +92,7 @@ fn copy_by_similarity_reports_limit_if_encountered() -> crate::Result {
             (Change::addition(), "a-cpy-2", "a"),
             (Change::modification(), "d", "ab"),
         ],
-    );
+    )?;
 
     let mut calls = 0;
     let out = util::assert_emit_with_objects(
@@ -132,6 +134,7 @@ fn copy_by_id() -> crate::Result {
             }),
             percentage: None,
             limit,
+            track_empty: false,
         };
         let mut track = util::new_tracker(rewrites);
         let odb = util::add_retained_blobs(
@@ -142,7 +145,7 @@ fn copy_by_id() -> crate::Result {
                 (Change::addition(), "a-cpy-2", "a"),
                 (Change::modification(), "d", "a"),
             ],
-        );
+        )?;
 
         let mut calls = 0;
         let out = util::assert_emit_with_objects(
@@ -206,6 +209,7 @@ fn copy_by_id_search_in_all_sources() -> crate::Result {
             }),
             percentage: None,
             limit,
+            track_empty: false,
         };
         let mut track = util::new_tracker(rewrites);
         let odb = util::add_retained_blobs(
@@ -214,7 +218,7 @@ fn copy_by_id_search_in_all_sources() -> crate::Result {
                 (Change::addition(), "a-cpy-1", "a"),
                 (Change::addition(), "a-cpy-2", "a"),
             ],
-        );
+        )?;
 
         let mut calls = 0;
         let content_id = hex_to_id("2e65efe2a145dda7ee51d1741299f848e5bf752e");
@@ -284,6 +288,7 @@ fn copy_by_50_percent_similarity() -> crate::Result {
         }),
         percentage: None,
         limit: 0,
+        track_empty: false,
     };
     let mut track = util::new_tracker(rewrites);
     let odb = util::add_retained_blobs(
@@ -294,7 +299,7 @@ fn copy_by_50_percent_similarity() -> crate::Result {
             (Change::addition(), "a-cpy-2", "a\nc"),
             (Change::modification(), "d", "a"),
         ],
-    );
+    )?;
 
     let mut calls = 0;
     let out = util::assert_emit_with_objects(
@@ -363,6 +368,7 @@ fn copy_by_id_in_additions_only() -> crate::Result {
         }),
         percentage: None,
         limit: 0,
+        track_empty: false,
     };
     let mut track = util::new_tracker(rewrites);
     let odb = util::add_retained_blobs(
@@ -371,7 +377,7 @@ fn copy_by_id_in_additions_only() -> crate::Result {
             (Change::modification(), "a", "a"),
             (Change::modification(), "a-cpy-1", "a"),
         ],
-    );
+    )?;
 
     let mut calls = 0;
     let out = util::assert_emit_with_objects(
@@ -413,6 +419,7 @@ fn rename_by_similarity_reports_limit_if_encountered() -> crate::Result {
         copies: None,
         percentage: Some(0.5),
         limit: 1,
+        track_empty: false,
     };
     let mut track = util::new_tracker(rewrites);
     let odb = util::add_retained_blobs(
@@ -422,7 +429,7 @@ fn rename_by_similarity_reports_limit_if_encountered() -> crate::Result {
             (Change::addition(), "b", "firt\nsecond\n"),
             (Change::addition(), "c", "second\nunrelated\n"),
         ],
-    );
+    )?;
 
     let mut calls = 0;
     let out = util::assert_emit_with_objects(
@@ -434,7 +441,7 @@ fn rename_by_similarity_reports_limit_if_encountered() -> crate::Result {
                 1 => assert_eq!(dst.location, "b"),
                 2 => assert_eq!(dst.location, "c"),
                 _ => panic!("too many elements emitted"),
-            };
+            }
             calls += 1;
             Action::Continue
         },
@@ -458,6 +465,7 @@ fn rename_by_50_percent_similarity() -> crate::Result {
         copies: None,
         percentage: Some(0.5),
         limit: 0,
+        track_empty: false,
     };
     let mut track = util::new_tracker(rewrites);
     let odb = util::add_retained_blobs(
@@ -467,7 +475,7 @@ fn rename_by_50_percent_similarity() -> crate::Result {
             (Change::addition(), "b", "firt\nsecond\n"),
             (Change::addition(), "c", "second\nunrelated\n"),
         ],
-    );
+    )?;
 
     let mut calls = 0;
     let out = util::assert_emit_with_objects(
@@ -503,7 +511,7 @@ fn rename_by_50_percent_similarity() -> crate::Result {
                     assert_eq!(dst.location, "c");
                 }
                 _ => panic!("too many elements emitted"),
-            };
+            }
             calls += 1;
             Action::Continue
         },
@@ -525,17 +533,19 @@ fn rename_by_50_percent_similarity() -> crate::Result {
 #[test]
 fn directories_without_relation_are_ignored() -> crate::Result {
     let mut track = util::new_tracker(Default::default());
-    let tree_without_relation = Change {
-        id: NULL_ID,
-        kind: ChangeKind::Deletion,
-        mode: EntryKind::Tree.into(),
-        relation: None,
-    };
-    assert_eq!(
-        track.try_push_change(tree_without_relation, "dir".into()),
-        Some(tree_without_relation),
-        "trees, or non-blobs, are ignored, particularly when they have no relation"
-    );
+    for mode in [EntryKind::Tree, EntryKind::Commit] {
+        let tree_without_relation = Change {
+            id: NULL_ID,
+            kind: ChangeKind::Deletion,
+            mode: mode.into(),
+            relation: None,
+        };
+        assert_eq!(
+            track.try_push_change(tree_without_relation, "dir".into()),
+            Some(tree_without_relation),
+            "trees and submodules are ignored, particularly when they have no relation"
+        );
+    }
     Ok(())
 }
 
@@ -545,6 +555,7 @@ fn directory_renames_by_id_can_fail_gracefully() -> crate::Result {
         copies: None,
         percentage: Some(0.5),
         limit: 0,
+        track_empty: false,
     };
     let mut track = util::new_tracker(rename_by_similarity);
     let tree_dst_id = 1;
@@ -585,7 +596,8 @@ fn directory_renames_by_id_can_fail_gracefully() -> crate::Result {
             (Change::deletion(), "a", "first\nsecond\n"),
             (Change::addition(), "b", "firt\nsecond\n"),
         ],
-    );
+    )?;
+
     let mut calls = 0;
     let out = util::assert_emit_with_objects(
         &mut track,
@@ -598,10 +610,17 @@ fn directory_renames_by_id_can_fail_gracefully() -> crate::Result {
                     assert_eq!(src.location, expected_src);
                     assert_eq!(dst.location, expected_dst);
                 }
-                3..=6 => {
+                3 => {
+                    assert_eq!(src.unwrap().location, "d");
+                    assert_eq!(
+                        dst.location, "d-renamed",
+                        "it can now track modified and renamed directories"
+                    );
+                }
+                4 => {
                     assert_eq!(src, None);
-                    let expected_dst = ["d", "d-renamed", "d/subdir/d"][calls - 3];
-                    assert_eq!(dst.location, expected_dst);
+                    assert_eq!(dst.change.kind, ChangeKind::Deletion);
+                    assert_eq!(dst.location, "d/subdir/d");
                 }
                 _ => unreachable!("Should have expected emission call {calls}"),
             }
@@ -618,7 +637,7 @@ fn directory_renames_by_id_can_fail_gracefully() -> crate::Result {
             ..Default::default()
         }
     );
-    assert_eq!(calls, 6, "Should not have too few calls");
+    assert_eq!(calls, 5, "Should not have too few calls");
     Ok(())
 }
 
@@ -628,6 +647,7 @@ fn simple_directory_rename_by_id() -> crate::Result {
         copies: None,
         percentage: None,
         limit: 0,
+        track_empty: false,
     };
     let mut track = util::new_tracker(renames_by_identity);
     let tree_dst_id = 1;
@@ -783,16 +803,16 @@ mod util {
     pub fn add_retained_blobs<'a>(
         tracker: &mut rewrites::Tracker<Change>,
         blobs: impl IntoIterator<Item = (Change, &'a str, &'a str)>,
-    ) -> ObjectDb {
+    ) -> crate::Result<ObjectDb> {
         let mut db = ObjectDb::default();
         for (mut change, location, data) in blobs {
-            change.id = db.insert(data);
+            change.id = db.insert(data)?;
             assert!(
                 tracker.try_push_change(change, location.into()).is_none(),
                 "input changes must be tracked"
             );
         }
-        db
+        Ok(db)
     }
 
     pub fn assert_emit(
