@@ -1,7 +1,8 @@
-use crate::index::Fixture;
 use bstr::{BString, ByteSlice};
 use gix_index::entry::Stage;
 
+use crate::index::Fixture;
+
 fn icase_fixture() -> gix_index::File {
     Fixture::Generated("v2_icase_name_clashes").open()
 }
@@ -214,6 +215,18 @@ fn remove_entries() {
     file.remove_entries(|_, _, _| unreachable!("should not be called"));
 }
 
+#[test]
+fn remove_entry_at_index() {
+    let mut file = Fixture::Loose("conflicting-file").open();
+
+    file.remove_entry_at_index(0);
+    assert_eq!(file.entries().len(), 2);
+    file.remove_entry_at_index(0);
+    assert_eq!(file.entries().len(), 1);
+    file.remove_entry_at_index(0);
+    assert_eq!(file.entries().len(), 0);
+}
+
 #[test]
 fn sort_entries() {
     let mut file = Fixture::Generated("v4_more_files_IEOT").open();
