@@ -21,12 +21,16 @@ pub enum Pick {
 }
 
 pub(super) mod function {
-    use crate::blob::builtin_driver::binary::{Pick, ResolveWith};
-    use crate::blob::Resolution;
+    use crate::blob::{
+        builtin_driver::binary::{Pick, ResolveWith},
+        Resolution,
+    };
 
     /// As this algorithm doesn't look at the actual data, it returns a choice solely based on logic.
+    /// This also means that the caller has to assure this only gets called if the input *doesn't* match.
     ///
-    /// It always results in a conflict with `current` being picked unless `on_conflict` is not `None`.
+    /// It always results in a conflict with `current` being picked unless `on_conflict` is not `None`,
+    /// which is when we always return [`Resolution::CompleteWithAutoResolvedConflict`].
     pub fn merge(on_conflict: Option<ResolveWith>) -> (Pick, Resolution) {
         match on_conflict {
             None => (Pick::Ours, Resolution::Conflict),
@@ -36,7 +40,7 @@ pub(super) mod function {
                     ResolveWith::Theirs => Pick::Theirs,
                     ResolveWith::Ancestor => Pick::Ancestor,
                 },
-                Resolution::Complete,
+                Resolution::CompleteWithAutoResolvedConflict,
             ),
         }
     }
