@@ -1,17 +1,23 @@
+use gix_merge::blob::Platform;
 use gix_worktree::stack::state::attributes;
 
-use gix_merge::blob::Platform;
-
 mod merge {
-    use crate::blob::platform::new_platform;
-    use crate::blob::util::ObjectDb;
+    use std::{convert::Infallible, process::Stdio};
+
     use bstr::{BStr, ByteSlice};
-    use gix_merge::blob::builtin_driver::text::ConflictStyle;
-    use gix_merge::blob::platform::builtin_merge::Pick;
-    use gix_merge::blob::platform::DriverChoice;
-    use gix_merge::blob::{builtin_driver, pipeline, platform, BuiltinDriver, Resolution, ResourceKind};
+    use gix_merge::blob::{
+        builtin_driver,
+        builtin_driver::text::ConflictStyle,
+        pipeline, platform,
+        platform::{builtin_merge::Pick, DriverChoice},
+        BuiltinDriver, Resolution, ResourceKind,
+    };
     use gix_object::tree::EntryKind;
-    use std::process::Stdio;
+
+    use crate::{
+        blob::{platform::new_platform, util::ObjectDb},
+        hex_to_id,
+    };
 
     #[test]
     fn builtin_text_uses_binary_if_needed() -> crate::Result {
@@ -29,7 +35,7 @@ mod merge {
             ("ours", ResourceKind::CurrentOrOurs),
             ("theirs\0", ResourceKind::OtherOrTheirs),
         ] {
-            let id = db.insert(content);
+            let id = db.insert(content)?;
             platform.set_resource(
                 id,
                 EntryKind::Blob,
@@ -46,7 +52,7 @@ mod merge {
         );
 
         let mut buf = Vec::new();
-        let res = platform_ref.merge(&mut buf, default_labels(), Default::default())?;
+        let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
         assert_eq!(
             res,
             (Pick::Ours, Resolution::Conflict),
@@ -54,20 +60,70 @@ mod merge {
         );
 
         platform_ref.options.resolve_binary_with = Some(builtin_driver::binary::ResolveWith::Theirs);
-        let res = platform_ref.merge(&mut buf, default_labels(), Default::default())?;
+        let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
         assert_eq!(
             res,
-            (Pick::Theirs, Resolution::Complete),
+            (Pick::Theirs, Resolution::CompleteWithAutoResolvedConflict),
             "the auto-binary driver respects its own options"
         );
         Ok(())
     }
 
+    #[test]
+    fn same_binaries_do_not_count_as_conflicted() -> crate::Result {
+        let mut platform = new_platform(None, pipeline::Mode::ToGit);
+        platform.set_resource(
+            gix_hash::Kind::Sha1.null(),
+            EntryKind::Blob,
+            "a".into(),
+            ResourceKind::CommonAncestorOrBase,
+            &gix_object::find::Never,
+        )?;
+
+        let mut db = ObjectDb::default();
+        for (content, kind) in [
+            ("any\0", ResourceKind::CurrentOrOurs),
+            ("any\0", ResourceKind::OtherOrTheirs),
+        ] {
+            let id = db.insert(content)?;
+            platform.set_resource(
+                id,
+                EntryKind::Blob,
+                "path matters only for attribute lookup".into(),
+                kind,
+                &db,
+            )?;
+        }
+        let platform_ref = platform.prepare_merge(&db, Default::default())?;
+        assert_eq!(
+            platform_ref.driver,
+            DriverChoice::BuiltIn(BuiltinDriver::Text),
+            "it starts out at the default text driver"
+        );
+
+        let mut buf = Vec::new();
+        let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
+        assert_eq!(
+            res,
+            (Pick::Ours, Resolution::Complete),
+            "as both are the same, it just picks ours, declaring it non-conflicting"
+        );
+
+        let mut input = imara_diff::intern::InternedInput::new(&[][..], &[]);
+        assert_eq!(
+            platform_ref.builtin_merge(BuiltinDriver::Binary, &mut buf, &mut input, default_labels()),
+            res,
+            "no way to work around it - calling the built-in binary merge is the same"
+        );
+        Ok(())
+    }
+
     #[test]
     fn builtin_with_conflict() -> crate::Result {
         let mut platform = new_platform(None, pipeline::Mode::ToGit);
+        let non_existing_ancestor_id = hex_to_id("ffffffffffffffffffffffffffffffffffffffff");
         platform.set_resource(
-            gix_hash::Kind::Sha1.null(),
+            non_existing_ancestor_id,
             EntryKind::Blob,
             "b".into(),
             ResourceKind::CommonAncestorOrBase,
@@ -79,14 +135,14 @@ mod merge {
             ("ours", ResourceKind::CurrentOrOurs),
             ("theirs", ResourceKind::OtherOrTheirs),
         ] {
-            let id = db.insert(content);
+            let id = db.insert(content)?;
             platform.set_resource(id, EntryKind::Blob, "b".into(), kind, &db)?;
         }
 
         let mut platform_ref = platform.prepare_merge(&db, Default::default())?;
         assert_eq!(platform_ref.driver, DriverChoice::BuiltIn(BuiltinDriver::Text));
         let mut buf = Vec::new();
-        let res = platform_ref.merge(&mut buf, default_labels(), Default::default())?;
+        let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
         assert_eq!(res, (Pick::Buffer, Resolution::Conflict));
         assert_eq!(
             buf.as_bstr(),
@@ -100,9 +156,9 @@ theirs
         );
         platform_ref.options.text.conflict = builtin_driver::text::Conflict::Keep {
             style: ConflictStyle::Diff3,
-            marker_size: 3,
+            marker_size: 3.try_into().unwrap(),
         };
-        let res = platform_ref.merge(&mut buf, default_labels(), Default::default())?;
+        let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
         assert_eq!(res, (Pick::Buffer, Resolution::Conflict));
 
         assert_eq!(
@@ -119,32 +175,32 @@ theirs
         );
 
         platform_ref.options.text.conflict = builtin_driver::text::Conflict::ResolveWithOurs;
-        let res = platform_ref.merge(&mut buf, default_labels(), Default::default())?;
+        let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
         assert_eq!(
             res,
-            (Pick::Buffer, Resolution::Complete),
-            "it's actually unclear now if there ever was a conflict, but we *could* compute it"
+            (Pick::Buffer, Resolution::CompleteWithAutoResolvedConflict),
+            "we can determine that there was a conflict, despite the resolution being complete"
         );
         assert_eq!(buf.as_bstr(), "ours");
 
         platform_ref.options.text.conflict = builtin_driver::text::Conflict::ResolveWithTheirs;
-        let res = platform_ref.merge(&mut buf, default_labels(), Default::default())?;
-        assert_eq!(res, (Pick::Buffer, Resolution::Complete));
+        let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
+        assert_eq!(res, (Pick::Buffer, Resolution::CompleteWithAutoResolvedConflict));
         assert_eq!(buf.as_bstr(), "theirs");
 
         platform_ref.options.text.conflict = builtin_driver::text::Conflict::ResolveWithUnion;
-        let res = platform_ref.merge(&mut buf, default_labels(), Default::default())?;
-        assert_eq!(res, (Pick::Buffer, Resolution::Complete));
+        let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
+        assert_eq!(res, (Pick::Buffer, Resolution::CompleteWithAutoResolvedConflict));
         assert_eq!(buf.as_bstr(), "ours\ntheirs");
 
         platform_ref.driver = DriverChoice::BuiltIn(BuiltinDriver::Union);
         platform_ref.options.text.conflict = builtin_driver::text::Conflict::default();
-        let res = platform_ref.merge(&mut buf, default_labels(), Default::default())?;
-        assert_eq!(res, (Pick::Buffer, Resolution::Complete));
+        let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
+        assert_eq!(res, (Pick::Buffer, Resolution::CompleteWithAutoResolvedConflict));
         assert_eq!(buf.as_bstr(), "ours\ntheirs");
 
         platform_ref.driver = DriverChoice::BuiltIn(BuiltinDriver::Binary);
-        let res = platform_ref.merge(&mut buf, default_labels(), Default::default())?;
+        let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
         assert_eq!(
             res,
             (Pick::Ours, Resolution::Conflict),
@@ -152,20 +208,56 @@ theirs
         );
         assert!(buf.is_empty(), "it tells us where to get the content from");
         assert_eq!(
-            platform_ref.buffer_by_pick(res.0).unwrap().as_bstr(),
+            platform_ref.buffer_by_pick(res.0).unwrap().unwrap().as_bstr(),
             "ours",
             "getting access to the content is simplified"
         );
+        assert_eq!(
+            platform_ref
+                .id_by_pick(res.0, &buf, |_buf| -> Result<_, Infallible> {
+                    panic!("no need to write buffer")
+                })
+                .unwrap()
+                .unwrap(),
+            hex_to_id("424860eef4edb9f5a2dacbbd6dc8c2d2e7645035"),
+            "there is no need to write a buffer here, it just returns one of our inputs"
+        );
 
-        for (expected, expected_pick, resolve) in [
-            ("ours", Pick::Ours, builtin_driver::binary::ResolveWith::Ours),
-            ("theirs", Pick::Theirs, builtin_driver::binary::ResolveWith::Theirs),
-            ("b\n", Pick::Ancestor, builtin_driver::binary::ResolveWith::Ancestor),
+        for (expected, expected_pick, resolve, expected_id) in [
+            (
+                "ours",
+                Pick::Ours,
+                builtin_driver::binary::ResolveWith::Ours,
+                hex_to_id("424860eef4edb9f5a2dacbbd6dc8c2d2e7645035"),
+            ),
+            (
+                "theirs",
+                Pick::Theirs,
+                builtin_driver::binary::ResolveWith::Theirs,
+                hex_to_id("228068dbe790983c15535164cd483eb77ade97e4"),
+            ),
+            (
+                "b\n",
+                Pick::Ancestor,
+                builtin_driver::binary::ResolveWith::Ancestor,
+                non_existing_ancestor_id,
+            ),
         ] {
             platform_ref.options.resolve_binary_with = Some(resolve);
-            let res = platform_ref.merge(&mut buf, default_labels(), Default::default())?;
-            assert_eq!(res, (expected_pick, Resolution::Complete));
-            assert_eq!(platform_ref.buffer_by_pick(res.0).unwrap().as_bstr(), expected);
+            let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
+            assert_eq!(res, (expected_pick, Resolution::CompleteWithAutoResolvedConflict));
+            assert_eq!(platform_ref.buffer_by_pick(res.0).unwrap().unwrap().as_bstr(), expected);
+
+            assert_eq!(
+                platform_ref
+                    .id_by_pick(res.0, &buf, |_buf| -> Result<_, Infallible> {
+                        panic!("no need to write buffer")
+                    })
+                    .unwrap()
+                    .unwrap(),
+                expected_id,
+                "{expected}: each input has an id, so it's just returned as is without handling buffers"
+            );
         }
 
         Ok(())
@@ -196,13 +288,13 @@ theirs
             ("ours", ResourceKind::CurrentOrOurs),
             ("theirs", ResourceKind::OtherOrTheirs),
         ] {
-            let id = db.insert(content);
+            let id = db.insert(content)?;
             platform.set_resource(id, EntryKind::Blob, "b".into(), kind, &db)?;
         }
 
         let platform_ref = platform.prepare_merge(&db, Default::default())?;
         let mut buf = Vec::new();
-        let res = platform_ref.merge(&mut buf, default_labels(), Default::default())?;
+        let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
         assert_eq!(res, (Pick::Buffer, Resolution::Complete), "merge drivers always merge ");
         let mut lines = cleaned_driver_lines(&buf)?;
         for tmp_file in lines.by_ref().take(3) {
@@ -225,15 +317,27 @@ theirs
             "we handle word-splitting and definitely pick-up what's written into the %A buffer"
         );
 
-        let id = db.insert("binary\0");
+        let id = db.insert("binary\0")?;
         platform.set_resource(id, EntryKind::Blob, "b".into(), ResourceKind::OtherOrTheirs, &db)?;
         let platform_ref = platform.prepare_merge(&db, Default::default())?;
-        let res = platform_ref.merge(&mut buf, default_labels(), Default::default())?;
+        let res = platform_ref.merge(&mut buf, default_labels(), &Default::default())?;
         assert_eq!(
             res,
             (Pick::Buffer, Resolution::Complete),
             "merge drivers deal with binary themselves"
         );
+        assert_eq!(
+            platform_ref.buffer_by_pick(res.0),
+            Ok(None),
+            "This indicates the buffer must be read"
+        );
+
+        let marker = hex_to_id("ffffffffffffffffffffffffffffffffffffffff");
+        assert_eq!(
+            platform_ref.id_by_pick(res.0, &buf, |_buf| Ok::<_, Infallible>(marker)),
+            Ok(Some(marker)),
+            "the id is created by hashing the merge buffer"
+        );
         let mut lines = cleaned_driver_lines(&buf)?;
         for tmp_file in lines.by_ref().take(3) {
             assert!(tmp_file.contains_str(&b".tmp"[..]), "{tmp_file}");
@@ -282,7 +386,7 @@ theirs
         let platform_ref = platform.prepare_merge(&gix_object::find::Never, Default::default())?;
 
         let mut buf = Vec::new();
-        let res = platform_ref.merge(&mut buf, Default::default(), Default::default())?;
+        let res = platform_ref.merge(&mut buf, Default::default(), &Default::default())?;
         assert_eq!(
             res,
             (Pick::Buffer, Resolution::Complete),
@@ -295,11 +399,7 @@ theirs
 
         let mut input = imara_diff::intern::InternedInput::new(&[][..], &[]);
         let res = platform_ref.builtin_merge(BuiltinDriver::Text, &mut buf, &mut input, Default::default());
-        assert_eq!(
-            res,
-            Some((Pick::Buffer, Resolution::Complete)),
-            "both versions are deleted"
-        );
+        assert_eq!(res, (Pick::Buffer, Resolution::Complete), "both versions are deleted");
         assert!(buf.is_empty(), "the result is the same on direct invocation");
 
         let print_all = "for arg in $@ %O %A %B %L %P %S %X %Y %F; do echo $arg; done";
@@ -358,24 +458,27 @@ theirs
         assert_eq!(platform_ref.other.data, platform::resource::Data::TooLarge { size: 12 });
 
         let mut out = Vec::new();
-        let err = platform_ref
-            .merge(&mut out, Default::default(), Default::default())
-            .unwrap_err();
-        assert!(matches!(err, platform::merge::Error::ResourceTooLarge));
+        let res = platform_ref.merge(&mut out, Default::default(), &Default::default())?;
+        assert_eq!(
+            res,
+            (Pick::Ours, Resolution::Conflict),
+            "this is the default for binary merges, which are used in this case"
+        );
 
         let mut input = imara_diff::intern::InternedInput::new(&[][..], &[]);
         assert_eq!(
-            platform_ref.builtin_merge(BuiltinDriver::Text, &mut out, &mut input, Default::default(),),
-            None
+            platform_ref.builtin_merge(BuiltinDriver::Text, &mut out, &mut input, Default::default()),
+            res,
+            "we can't enforce it, it will just default to using binary"
         );
 
         let err = platform_ref
             .prepare_external_driver("bogus".into(), Default::default(), Default::default())
             .unwrap_err();
-        assert!(matches!(
-            err,
-            platform::prepare_external_driver::Error::ResourceTooLarge { .. }
-        ));
+        assert!(
+            matches!(err, platform::prepare_external_driver::Error::ResourceTooLarge { .. }),
+            "however, for external drivers, resources can still be too much to handle, until we learn how to stream them"
+        );
         Ok(())
     }
 
@@ -396,11 +499,15 @@ theirs
 }
 
 mod prepare_merge {
-    use crate::blob::platform::new_platform;
-    use gix_merge::blob::platform::{resource, DriverChoice};
-    use gix_merge::blob::{builtin_driver, pipeline, BuiltinDriver, ResourceKind};
+    use gix_merge::blob::{
+        builtin_driver, pipeline,
+        platform::{resource, DriverChoice},
+        BuiltinDriver, ResourceKind,
+    };
     use gix_object::tree::EntryKind;
 
+    use crate::blob::platform::new_platform;
+
     #[test]
     fn ancestor_and_current_and_other_do_not_exist() -> crate::Result {
         let mut platform = new_platform(None, pipeline::Mode::ToGit);
@@ -464,7 +571,7 @@ mod prepare_merge {
         platform.set_resource(
             gix_hash::Kind::Sha1.null(),
             EntryKind::Blob,
-            "just-set".into(),
+            "ancestor does not matter for attributes".into(),
             ResourceKind::CommonAncestorOrBase,
             &gix_object::find::Never,
         )?;
@@ -472,7 +579,7 @@ mod prepare_merge {
         platform.set_resource(
             gix_hash::Kind::Sha1.null(),
             EntryKind::Blob,
-            "does not matter for driver".into(),
+            "just-set".into(),
             ResourceKind::CurrentOrOurs,
             &gix_object::find::Never,
         )?;
@@ -490,6 +597,11 @@ mod prepare_merge {
             DriverChoice::BuiltIn(BuiltinDriver::Text),
             "`merge` attribute means text"
         );
+        assert_eq!(
+            prepared.options.text.conflict.marker_size(),
+            Some(32),
+            "marker sizes are picked up from attributes as well"
+        );
 
         platform.set_resource(
             gix_hash::Kind::Sha1.null(),
@@ -585,7 +697,7 @@ mod prepare_merge {
             },
         )?;
         let expected_idx = 1;
-        assert_eq!(prepared.driver, DriverChoice::Index(expected_idx),);
+        assert_eq!(prepared.driver, DriverChoice::Index(expected_idx));
         assert_eq!(
             prepared.options.resolve_binary_with,
             Some(builtin_driver::binary::ResolveWith::Ours),
@@ -601,10 +713,11 @@ mod prepare_merge {
 }
 
 mod set_resource {
-    use crate::blob::platform::new_platform;
     use gix_merge::blob::{pipeline, ResourceKind};
     use gix_object::tree::EntryKind;
 
+    use crate::blob::platform::new_platform;
+
     #[test]
     fn invalid_resource_types() {
         let mut platform = new_platform(None, pipeline::Mode::ToGit);
