@@ -8,7 +8,7 @@ fn find_header(db: impl gix_odb::Header, hex_id: &str) -> gix_odb::find::Header
 
 #[test]
 fn loose_object() {
-    find_header(&db(), "37d4e6c5c48ba0d245164c4e10d5f41140cab980");
+    find_header(db(), "37d4e6c5c48ba0d245164c4e10d5f41140cab980");
 }
 
 #[test]
