@@ -1,6 +1,7 @@
+use std::path::Path;
+
 use bstr::BStr;
 use gix_pathspec::search::MatchKind::*;
-use std::path::Path;
 
 #[test]
 fn directories() -> crate::Result {
@@ -644,7 +645,7 @@ mod baseline {
                                 attrs.pattern_matching_relative_path(rela_path, case, Some(is_dir), out)
                             },
                         )
-                        .map_or(false, |m| !m.is_excluded())
+                        .is_some_and(|m| !m.is_excluded())
                 })
                 .cloned()
                 .collect();
