@@ -5,14 +5,15 @@ use std::sync::{
 
 use bstr::BStr;
 use filetime::{set_file_mtime, FileTime};
+use gix_filter::eol::AutoCrlf;
 use gix_index as index;
-use gix_index::Entry;
-use gix_status::index_as_worktree::Context;
+use gix_index::{entry, Entry};
 use gix_status::{
     index_as_worktree,
     index_as_worktree::{
         traits::{CompareBlobs, FastEq, ReadData, SubmoduleStatus},
-        Change as WorktreeChange, Conflict, EntryStatus as WorktreeEntryStatus, Options, Outcome, Record, Recorder,
+        Change as WorktreeChange, Conflict, Context, EntryStatus as WorktreeEntryStatus, Options, Outcome, Record,
+        Recorder,
     },
 };
 
@@ -37,30 +38,95 @@ fn fixture(name: &str, expected_status: &[Expectation<'_>]) -> Outcome {
     fixture_filtered(name, &[], expected_status)
 }
 
+fn nonfile_fixture(name: &str, expected_status: &[Expectation<'_>]) -> Outcome {
+    fixture_filtered_detailed(
+        "status_nonfile",
+        name,
+        &[],
+        expected_status,
+        |_| {},
+        false,
+        Default::default(),
+        false,
+        None,
+    )
+}
+
 fn fixture_with_index(
     name: &str,
     prepare_index: impl FnMut(&mut gix_index::State),
     expected_status: &[Expectation<'_>],
 ) -> Outcome {
-    fixture_filtered_detailed(name, "", &[], expected_status, prepare_index, false)
+    fixture_filtered_detailed(
+        name,
+        "",
+        &[],
+        expected_status,
+        prepare_index,
+        false,
+        Default::default(),
+        false,
+        None,
+    )
 }
 
 fn submodule_fixture(name: &str, expected_status: &[Expectation<'_>]) -> Outcome {
-    fixture_filtered_detailed("status_submodule", name, &[], expected_status, |_| {}, false)
+    fixture_filtered_detailed(
+        "status_submodule",
+        name,
+        &[],
+        expected_status,
+        |_| {},
+        false,
+        Default::default(),
+        false,
+        None,
+    )
 }
 
 fn conflict_fixture(name: &str, expected_status: &[Expectation<'_>]) -> Outcome {
-    fixture_filtered_detailed("conflicts", name, &[], expected_status, |_| {}, false)
+    fixture_filtered_detailed(
+        "conflicts",
+        name,
+        &[],
+        expected_status,
+        |_| {},
+        false,
+        Default::default(),
+        false,
+        None,
+    )
 }
 
 fn submodule_fixture_status(name: &str, expected_status: &[Expectation<'_>], submodule_dirty: bool) -> Outcome {
-    fixture_filtered_detailed("status_submodule", name, &[], expected_status, |_| {}, submodule_dirty)
+    fixture_filtered_detailed(
+        "status_submodule",
+        name,
+        &[],
+        expected_status,
+        |_| {},
+        submodule_dirty,
+        Default::default(),
+        false,
+        None,
+    )
 }
 
 fn fixture_filtered(name: &str, pathspecs: &[&str], expected_status: &[Expectation<'_>]) -> Outcome {
-    fixture_filtered_detailed(name, "", pathspecs, expected_status, |_| {}, false)
+    fixture_filtered_detailed(
+        name,
+        "",
+        pathspecs,
+        expected_status,
+        |_| {},
+        false,
+        Default::default(),
+        false,
+        None,
+    )
 }
 
+#[allow(clippy::too_many_arguments)]
 fn fixture_filtered_detailed(
     name: &str,
     subdir: &str,
@@ -68,6 +134,9 @@ fn fixture_filtered_detailed(
     expected_status: &[Expectation<'_>],
     mut prepare_index: impl FnMut(&mut gix_index::State),
     submodule_dirty: bool,
+    auto_crlf: gix_filter::eol::AutoCrlf,
+    use_odb: bool,
+    fs_capabilities: Option<&dyn Fn(&std::path::Path) -> gix_fs::Capabilities>,
 ) -> Outcome {
     // This can easily happen in some fixtures, which can cause flakiness. It's time-dependent after all.
     fn ignore_racyclean(mut out: Outcome) -> Outcome {
@@ -101,26 +170,53 @@ fn fixture_filtered_detailed(
         &index,
         index.path_backing(),
     );
-    let outcome = index_as_worktree(
-        &index,
-        &worktree,
-        &mut recorder,
-        FastEq,
-        SubmoduleStatusMock { dirty: submodule_dirty },
-        gix_object::find::Never,
-        &mut gix_features::progress::Discard,
-        Context {
-            pathspec: search,
-            stack,
-            filter: Default::default(),
-            should_interrupt: &AtomicBool::default(),
-        },
-        Options {
-            fs: gix_fs::Capabilities::probe(&git_dir),
-            stat: TEST_OPTIONS,
-            ..Options::default()
-        },
-    )
+    let ctx = Context {
+        pathspec: search,
+        stack,
+        filter: gix_filter::Pipeline::new(
+            Default::default(),
+            gix_filter::pipeline::Options {
+                eol_config: gix_filter::eol::Configuration {
+                    auto_crlf,
+                    ..Default::default()
+                },
+                ..Default::default()
+            },
+        ),
+        should_interrupt: &AtomicBool::default(),
+    };
+    let options = Options {
+        fs: fs_capabilities.map_or_else(|| gix_fs::Capabilities::probe(&git_dir), |new| new(&git_dir)),
+        stat: TEST_OPTIONS,
+        ..Options::default()
+    };
+    let outcome = if use_odb {
+        let odb = gix_odb::at(git_dir.join("objects")).unwrap().into_arc().unwrap();
+        index_as_worktree(
+            &index,
+            &worktree,
+            &mut recorder,
+            FastEq,
+            SubmoduleStatusMock { dirty: submodule_dirty },
+            odb,
+            &mut gix_features::progress::Discard,
+            ctx,
+            options,
+        )
+    } else {
+        let odb = gix_object::find::Never;
+        index_as_worktree(
+            &index,
+            &worktree,
+            &mut recorder,
+            FastEq,
+            SubmoduleStatusMock { dirty: submodule_dirty },
+            &odb,
+            &mut gix_features::progress::Discard,
+            ctx,
+            options,
+        )
+    }
     .unwrap();
     recorder.records.sort_unstable_by_key(|r| r.relative_path);
     assert_eq!(records_to_tuple(recorder.records), expected_status);
@@ -142,7 +238,7 @@ fn deracify_status(status: EntryStatus) -> Option<EntryStatus> {
         EntryStatus::Conflict(c) => EntryStatus::Conflict(c),
         EntryStatus::Change(c) => match c {
             Change::Removed => Change::Removed,
-            Change::Type => Change::Type,
+            Change::Type { worktree_mode } => Change::Type { worktree_mode },
             Change::Modification {
                 executable_bit_changed,
                 content_change,
@@ -185,6 +281,29 @@ fn status_removed() -> EntryStatus {
     Change::Removed.into()
 }
 
+#[test]
+#[cfg(unix)]
+fn nonfile_untracked_are_not_visible() {
+    // And generally, untracked aren't visible here.
+    nonfile_fixture("untracked", &[]);
+}
+
+#[test]
+#[cfg(unix)]
+fn tracked_changed_to_non_file() {
+    nonfile_fixture(
+        "tracked-swapped",
+        &[(
+            BStr::new(b"file"),
+            0,
+            Change::Type {
+                worktree_mode: entry::Mode::FILE,
+            }
+            .into(),
+        )],
+    );
+}
+
 #[test]
 fn removed() {
     let out = fixture(
@@ -226,6 +345,34 @@ fn removed() {
     );
 }
 
+#[test]
+fn replace_dir_with_file() {
+    let out = fixture_filtered_detailed(
+        "status_many",
+        "replace-dir-with-file",
+        &[],
+        &[
+            (BStr::new(b"dir/content"), 0, status_removed()),
+            (BStr::new(b"dir/content2"), 1, status_removed()),
+            (BStr::new(b"dir/sub/nested"), 2, status_removed()),
+        ],
+        |_| {},
+        false,
+        Default::default(),
+        false,
+        None,
+    );
+    assert_eq!(
+        out,
+        Outcome {
+            entries_to_process: 5,
+            entries_processed: 5,
+            symlink_metadata_calls: if cfg!(windows) { 5 } else { 4 },
+            ..Default::default()
+        }
+    );
+}
+
 #[test]
 fn subomdule_nochange() {
     assert_eq!(
@@ -255,7 +402,17 @@ fn subomdule_deleted_dir() {
 #[test]
 fn subomdule_typechange() {
     assert_eq!(
-        submodule_fixture("type-change", &[(BStr::new(b"m1"), 1, Change::Type.into())]),
+        submodule_fixture(
+            "type-change",
+            &[(
+                BStr::new(b"m1"),
+                1,
+                Change::Type {
+                    worktree_mode: entry::Mode::FILE
+                }
+                .into()
+            )]
+        ),
         Outcome {
             entries_to_process: 2,
             entries_processed: 2,
@@ -411,6 +568,47 @@ fn unchanged() {
     fixture("status_unchanged", &[]);
 }
 
+#[test]
+fn unchanged_symlinks_present_but_deactivated() {
+    fixture_filtered_detailed(
+        "status_unchanged",
+        "",
+        &[],
+        &[],
+        |_| {},
+        false,
+        Default::default(),
+        false,
+        Some(&|dir| gix_fs::Capabilities {
+            symlink: false,
+            ..gix_fs::Capabilities::probe(dir)
+        }),
+    );
+}
+
+#[test]
+fn unchanged_despite_filter() {
+    let actual_outcome = fixture_filtered_detailed(
+        "status_unchanged_filter",
+        "",
+        &[],
+        &[],
+        |_| {},
+        false,
+        AutoCrlf::Enabled,
+        true, /* make ODB available */
+        None,
+    );
+
+    let expected_outcome = Outcome {
+        entries_to_process: 5,
+        entries_processed: 5,
+        symlink_metadata_calls: 5,
+        ..Default::default()
+    };
+    assert_eq!(actual_outcome, expected_outcome);
+}
+
 #[test]
 fn refresh() {
     let expected_outcome = Outcome {
@@ -445,7 +643,14 @@ fn refresh() {
                     }
                     .into(),
                 ),
-                (BStr::new(b"empty"), 3, Change::Type.into()),
+                (
+                    BStr::new(b"empty"),
+                    3,
+                    Change::Type {
+                        worktree_mode: entry::Mode::SYMLINK
+                    }
+                    .into()
+                ),
                 (
                     BStr::new(b"executable"),
                     4,
@@ -469,7 +674,14 @@ fn refresh() {
                     }
                     .into(),
                 ),
-                (BStr::new("empty"), 3, Change::Type.into()),
+                (
+                    BStr::new("empty"),
+                    3,
+                    Change::Type {
+                        worktree_mode: entry::Mode::SYMLINK
+                    }
+                    .into()
+                ),
                 (
                     BStr::new("executable"),
                     4,
@@ -518,7 +730,14 @@ fn modified() {
                 }
                 .into(),
             ),
-            (BStr::new(b"empty"), 3, Change::Type.into()),
+            (
+                BStr::new(b"empty"),
+                3,
+                Change::Type {
+                    worktree_mode: entry::Mode::SYMLINK,
+                }
+                .into(),
+            ),
             (
                 BStr::new(b"executable"),
                 4,
@@ -542,7 +761,14 @@ fn modified() {
                 }
                 .into(),
             ),
-            (BStr::new("empty"), 3, Change::Type.into()),
+            (
+                BStr::new("empty"),
+                3,
+                Change::Type {
+                    worktree_mode: entry::Mode::SYMLINK,
+                }
+                .into(),
+            ),
             (
                 BStr::new("executable"),
                 4,
@@ -555,7 +781,7 @@ fn modified() {
             ),
         ],
     );
-    assert_eq!(actual_outcome, expected_outcome,);
+    assert_eq!(actual_outcome, expected_outcome);
 }
 
 #[test]
