@@ -1,15 +1,15 @@
-use crate::status::fixture_path;
 use bstr::ByteSlice;
-use gix_diff::blob::pipeline::WorktreeRoots;
-use gix_diff::rewrites::CopySource;
-use gix_status::index_as_worktree::traits::FastEq;
-use gix_status::index_as_worktree::{Change, EntryStatus};
-use gix_status::index_as_worktree_with_renames;
-use gix_status::index_as_worktree_with_renames::{
-    Context, DirwalkContext, Entry, Options, Outcome, Recorder, Sorting, Summary,
+use gix_diff::{blob::pipeline::WorktreeRoots, rewrites::CopySource};
+use gix_index::entry;
+use gix_status::{
+    index_as_worktree::{traits::FastEq, Change, EntryStatus},
+    index_as_worktree_with_renames,
+    index_as_worktree_with_renames::{Context, DirwalkContext, Entry, Options, Outcome, Recorder, Sorting, Summary},
 };
 use pretty_assertions::assert_eq;
 
+use crate::fixture_path;
+
 #[test]
 fn changed_and_untracked_and_renamed() {
     let expectations_with_dirwalk = [
@@ -80,8 +80,10 @@ fn changed_and_untracked_and_renamed() {
         }),
         percentage: Some(0.3),
         limit: 0,
+        track_empty: true,
     };
     let out = fixture_filtered_detailed(
+        "status_many.sh",
         "changed-and-untracked-and-renamed",
         &[],
         &expectations_with_dirwalk,
@@ -99,9 +101,41 @@ fn changed_and_untracked_and_renamed() {
     );
 }
 
+#[test]
+#[cfg(unix)]
+fn nonfile_untracked_are_not_visible() {
+    fixture_filtered_detailed(
+        "status_nonfile.sh",
+        "untracked",
+        &[],
+        &[],
+        None,
+        Some(Default::default()),
+    );
+}
+
+#[test]
+#[cfg(unix)]
+fn tracked_changed_to_non_file() {
+    fixture_filtered_detailed(
+        "status_nonfile.sh",
+        "tracked-swapped",
+        &[],
+        &[Expectation::Modification {
+            rela_path: "file",
+            status: Change::Type {
+                worktree_mode: entry::Mode::FILE,
+            }
+            .into(),
+        }],
+        None,
+        Some(Default::default()),
+    );
+}
 #[test]
 fn changed_and_untracked() {
     let out = fixture_filtered_detailed(
+        "status_many.sh",
         "changed-and-untracked",
         &[],
         &[Expectation::Modification {
@@ -143,6 +177,7 @@ fn changed_and_untracked() {
         },
     ];
     let out = fixture_filtered_detailed(
+        "status_many.sh",
         "changed-and-untracked",
         &[],
         &expectations_with_dirwalk,
@@ -162,6 +197,7 @@ fn changed_and_untracked() {
     assert_eq!(out.rewrites, None, "rewrites are still not configured");
 
     let out = fixture_filtered_detailed(
+        "status_many.sh",
         "changed-and-untracked",
         &[],
         &expectations_with_dirwalk,
@@ -178,6 +214,7 @@ fn changed_and_untracked() {
 }
 
 fn fixture_filtered_detailed(
+    script: &str,
     subdir: &str,
     pathspecs: &[&str],
     expected: &[Expectation<'_>],
@@ -192,11 +229,11 @@ fn fixture_filtered_detailed(
         out
     }
 
-    let worktree = fixture_path("status_many.sh").join(subdir);
+    let worktree = fixture_path(script).join(subdir);
     let git_dir = worktree.join(".git");
     let index = gix_index::File::at(git_dir.join("index"), gix_hash::Kind::Sha1, false, Default::default()).unwrap();
     let search = gix_pathspec::Search::from_specs(
-        crate::status::index_as_worktree::to_pathspecs(pathspecs),
+        crate::index_as_worktree::to_pathspecs(pathspecs),
         None,
         std::path::Path::new(""),
     )
@@ -246,7 +283,7 @@ fn fixture_filtered_detailed(
         object_hash: gix_hash::Kind::Sha1,
         tracked_file_modifications: gix_status::index_as_worktree::Options {
             fs: capabilities,
-            stat: crate::status::index_as_worktree::TEST_OPTIONS,
+            stat: crate::index_as_worktree::TEST_OPTIONS,
             ..Default::default()
         },
         dirwalk,
@@ -261,7 +298,7 @@ fn fixture_filtered_detailed(
         &worktree,
         &mut recorder,
         FastEq,
-        crate::status::index_as_worktree::SubmoduleStatusMock { dirty: false },
+        crate::index_as_worktree::SubmoduleStatusMock { dirty: false },
         objects,
         &mut gix_features::progress::Discard,
         context,
@@ -359,7 +396,7 @@ impl Expectation<'_> {
                 EntryStatus::Conflict(_) => Summary::Conflict,
                 EntryStatus::Change(change) => match change {
                     Change::Removed => Summary::Removed,
-                    Change::Type => Summary::TypeChange,
+                    Change::Type { .. } => Summary::TypeChange,
                     Change::Modification { .. } | Change::SubmoduleModification(_) => Summary::Modified,
                 },
                 EntryStatus::NeedsUpdate(_) => return None,
