@@ -123,14 +123,14 @@ fn http_will_use_pipelining() {
         }
     });
 
-    let url = format!("http://{}:{}/reponame", &addr.ip().to_string(), &addr.port(),);
+    let url = format!("http://{}:{}/reponame", &addr.ip().to_string(), &addr.port());
     let mut client =
         gix_transport::client::http::connect(url.try_into().expect("valid url"), gix_transport::Protocol::V2, false);
     match client.handshake(gix_transport::Service::UploadPack, &[]) {
         Ok(_) => unreachable!("expecting permission denied to be detected"),
         Err(gix_transport::client::Error::Io(err)) if err.kind() == std::io::ErrorKind::PermissionDenied => {}
         Err(err) => unreachable!("{err:?}"),
-    };
+    }
     client
         .set_identity(gix_sec::identity::Account {
             username: "foo".into(),
@@ -141,7 +141,7 @@ fn http_will_use_pipelining() {
         Ok(_) => unreachable!("expecting permission denied to be detected"),
         Err(gix_transport::client::Error::Io(err)) if err.kind() == std::io::ErrorKind::PermissionDenied => {}
         Err(err) => unreachable!("{err:?}"),
-    };
+    }
     thread.join().unwrap();
 }
 
