@@ -15,7 +15,7 @@ tests_windows=()
 for path in "repo" "re:po" "re/po"; do
   # normal urls
   for protocol in "ssh+git" "git+ssh" "git" "ssh"; do
-    for host in "host" "user@host" "user@[::1]" "user@::1"; do
+    for host in "host" "user@host" "user_name@host" "user@[::1]" "user@::1"; do
       for port_separator in "" ":"; do
         tests+=("$protocol://$host$port_separator/$path")
 
@@ -42,7 +42,7 @@ for path in "repo" "re:po" "re/po"; do
     tests+=("./$protocol:$host/~$path")
   done
   # SCP like urls
-  for host in "host" "[::1]"; do
+  for host in "user@name@host" "user_name@host" "host" "[::1]"; do
     tests+=("$host:$path")
     tests+=("$host:/~$path")
   done
@@ -55,14 +55,21 @@ tests_windows+=("c:repo")
 tests_unix+=("${tests[@]}")
 tests_windows+=("${tests[@]}")
 
+# We will run `git fetch-pack` in this repo instead of the outer gitoxide repo,
+# for full isolation. This avoids assuming there *is* a gitoxide repo, and also
+# avoids `safe.directory` errors if the gitoxide repo has unusual ownership.
+git init -q temp-repo
+
 for url in "${tests_unix[@]}"
 do
   echo ";" # there are no `;` in the tested urls
-  git fetch-pack --diag-url "$url"
+  git -C temp-repo fetch-pack --diag-url "$url"
 done >git-baseline.unix
 
 for url in "${tests_windows[@]}"
 do
   echo ";" # there are no `;` in the tested urls
-  git fetch-pack --diag-url "$url"
+  git -C temp-repo fetch-pack --diag-url "$url"
 done >git-baseline.windows
+
+rm -rf temp-repo
