@@ -6,7 +6,7 @@ fn valid() {
         gix_validate::submodule::name(name.into()).map(|_| ())
     }
 
-    for valid_name in ["a/./b/..[", "..a/./b/", "..a\\./b\\", "你好"] {
+    for valid_name in ["a/./b/..[", "..a/./b/", r"..a\./b\", "你好"] {
         validate(valid_name).unwrap_or_else(|err| panic!("{valid_name} should be valid: {err:?}"));
     }
 }
@@ -31,7 +31,7 @@ mod invalid {
     mktest!(parent_component_in_middle, b"hi/../ho", ParentComponent);
     mktest!(ends_with_parent_component, b"hi/ho/..", ParentComponent);
     mktest!(only_parent_component, b"..", ParentComponent);
-    mktest!(starts_with_parent_component_backslash, b"..\\", ParentComponent);
-    mktest!(parent_component_in_middle_backslash, b"hi\\..\\ho", ParentComponent);
-    mktest!(ends_with_parent_component_backslash, b"hi\\ho\\..", ParentComponent);
+    mktest!(starts_with_parent_component_backslash, br"..\", ParentComponent);
+    mktest!(parent_component_in_middle_backslash, br"hi\..\ho", ParentComponent);
+    mktest!(ends_with_parent_component_backslash, br"hi\ho\..", ParentComponent);
 }
