@@ -30,7 +30,7 @@ static DRIVER: Lazy<PathBuf> = Lazy::new(|| {
         .join("debug")
         .join("examples")
         .join(if cfg!(windows) { "arrow.exe" } else { "arrow" });
-    assert!(path.is_file(), "Expecting driver to be located at {path:?}");
+    assert!(path.is_file(), "Expecting driver to be located at {}", path.display());
     path
 });
 
@@ -100,7 +100,7 @@ fn accidental_writes_through_symlinks_are_prevented_if_overwriting_is_forbidden(
         assert_eq!(stripped_prefix(&source_tree, &source_files), paths(expected));
         assert_eq!(stripped_prefix(&destination, &worktree_files), paths(expected));
         assert!(outcome.collisions.is_empty());
-    };
+    }
 }
 
 #[test]
@@ -122,7 +122,7 @@ fn writes_through_symlinks_are_prevented_even_if_overwriting_is_allowed() {
         assert_eq!(
             stripped_prefix(&destination, &worktree_files),
             paths([
-                if cfg!(windows) { "A-dir\\a" } else { "A-dir/a" },
+                if cfg!(windows) { r"A-dir\a" } else { "A-dir/a" },
                 "A-file",
                 "FAKE-DIR",
                 "FAKE-FILE"
@@ -134,7 +134,7 @@ fn writes_through_symlinks_are_prevented_even_if_overwriting_is_allowed() {
         assert_eq!(stripped_prefix(&source_tree, &source_files), paths(expected));
         assert_eq!(stripped_prefix(&destination, &worktree_files), paths(expected));
         assert!(outcome.collisions.is_empty());
-    };
+    }
 }
 
 #[test]
@@ -173,20 +173,13 @@ fn delayed_driver_process() -> crate::Result {
 }
 
 #[test]
-#[cfg_attr(
-    windows,
-    ignore = "on windows, the symlink to a directory doesn't seem to work and we really want to test with symlinks"
-)]
 fn overwriting_files_and_lone_directories_works() -> crate::Result {
     for delay in [
         gix_filter::driver::apply::Delay::Allow,
         gix_filter::driver::apply::Delay::Forbid,
     ] {
         let mut opts = opts_from_probe();
-        assert!(
-            opts.fs.symlink,
-            "BUG: the probe must detect to be able to generate symlinks"
-        );
+        assert!(opts.fs.symlink, "The probe must detect to be able to generate symlinks");
         opts.overwrite_existing = true;
         opts.filter_process_delay = delay;
         opts.destination_is_initially_empty = false;
@@ -227,9 +220,32 @@ fn overwriting_files_and_lone_directories_works() -> crate::Result {
 
         let meta = std::fs::symlink_metadata(exe)?;
         assert!(meta.is_file());
+        #[cfg(unix)]
         if opts.fs.executable_bit {
-            #[cfg(unix)]
-            assert_eq!(meta.mode() & 0o700, 0o700, "the executable bit is set where supported");
+            let mode = meta.mode();
+            assert_eq!(
+                mode & 0o100,
+                0o100,
+                "executable bit set where supported ({:04o} & {:04o} = {:04o} should be {:04o})",
+                mode,
+                0o100,
+                mode & 0o100,
+                0o100
+            );
+            let umask_write = gix_testtools::umask() & 0o222;
+            assert_eq!(
+                mode & umask_write,
+                0,
+                "no excessive write bits are set ({:04o} & {:04o} = {:04o} should be {:04o})",
+                mode,
+                umask_write,
+                mode & umask_write,
+                0
+            );
+            assert_ne!(
+                umask_write, 0,
+                "test not meaningful unless runner umask restricts some writes"
+            );
         }
 
         assert_eq!(
@@ -244,8 +260,7 @@ fn overwriting_files_and_lone_directories_works() -> crate::Result {
         );
 
         let symlink = destination.path().join("dir/sub-dir/symlink");
-        // on windows, git won't create symlinks as its probe won't detect the capability, even though we do.
-        assert_eq!(std::fs::symlink_metadata(&symlink)?.is_symlink(), cfg!(unix));
+        assert!(std::fs::symlink_metadata(&symlink)?.is_symlink());
         assert_eq!(
             std::fs::read(symlink)?.as_bstr(),
             "➡other content\r\n",
@@ -270,10 +285,7 @@ fn symlinks_become_files_if_disabled() -> crate::Result {
 #[test]
 fn symlinks_to_directories_are_usable() -> crate::Result {
     let opts = opts_from_probe();
-    if !opts.fs.symlink {
-        eprintln!("Skipping directory symlink test on filesystem that doesn't support it");
-        return Ok(());
-    }
+    assert!(opts.fs.symlink, "The probe must detect to be able to generate symlinks");
 
     let (_source_tree, destination, _index, outcome) =
         checkout_index_in_tmp_dir(opts.clone(), "make_dir_symlink", None)?;
@@ -298,10 +310,7 @@ fn symlinks_to_directories_are_usable() -> crate::Result {
 #[test]
 fn dangling_symlinks_can_be_created() -> crate::Result {
     let opts = opts_from_probe();
-    if !opts.fs.symlink {
-        eprintln!("Skipping dangling symlink test on filesystem that doesn't support it");
-        return Ok(());
-    }
+    assert!(opts.fs.symlink, "The probe must detect to be able to generate symlinks");
 
     for (fixture, symlink_name, target_name) in [
         ("make_dangling_symlink", "dangling", "non-existing-target"),
@@ -398,7 +407,7 @@ fn keep_going_collects_results() {
                 if cfg!(unix) {
                     "dir/sub-dir/symlink"
                 } else {
-                    "dir\\sub-dir\\symlink"
+                    r"dir\sub-dir\symlink"
                 },
                 "empty",
                 "executable",
