@@ -4,7 +4,7 @@ use gix::{prelude::ObjectIdExt, Reference};
 
 fn main() -> Result<(), Box<dyn std::error::Error>> {
     let mut repo = gix::discover(".")?;
-    println!("Repo: {}", repo.work_dir().unwrap_or_else(|| repo.git_dir()).display());
+    println!("Repo: {}", repo.workdir().unwrap_or_else(|| repo.git_dir()).display());
     let mut max_parents = 0;
     let mut avg_parents = 0;
     repo.object_cache_size(32 * 1024);
@@ -39,7 +39,6 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 
     let mut delegate = visit::Tree::new(repo.clone());
     tree.traverse().breadthfirst(&mut delegate)?;
-    let _files = tree.traverse().breadthfirst.files()?;
 
     println!("num trees: {}", delegate.num_trees);
     println!("num blobs: {}", delegate.num_blobs);
@@ -105,6 +104,8 @@ mod visit {
         }
     }
     impl gix_traverse::tree::Visit for Tree {
+        fn pop_back_tracked_path_and_set_current(&mut self) {}
+
         fn pop_front_tracked_path_and_set_current(&mut self) {}
 
         fn push_back_tracked_path_component(&mut self, _component: &BStr) {}
