@@ -175,3 +175,25 @@ git init ssl-no-verify-enabled
   git config http.sslVerify true
   git config gitoxide.http.sslNoVerify true
 )
+
+
+git init --bare with-hasconfig
+(cd with-hasconfig
+  cat >include-with-url <<-\EOF
+  [user]
+    name = "works"
+    email = "works@example.com"
+EOF
+  cat >system.config <<-\EOF
+  [includeIf "hasconfig:remote.*.url:anyurl"]
+    path = "include-with-url"
+EOF
+
+  echo $'[remote "any"]\n\turl=anyurl' >>config
+
+)
+
+git init big-file-threshold
+(cd big-file-threshold
+  git config core.bigFileThreshold 42
+)
