@@ -85,6 +85,114 @@ mod blocking_and_async_io {
         try_repo_rw(name).unwrap()
     }
 
+    #[test]
+    #[cfg(feature = "blocking-network-client")]
+    fn fetch_more_packs_than_can_be_handled() -> gix_testtools::Result {
+        use gix::{config::tree::User, interrupt::IS_INTERRUPTED};
+        use gix_odb::store::init::Slots;
+        use gix_testtools::tempfile;
+        fn create_empty_commit(repo: &gix::Repository) -> anyhow::Result<()> {
+            let name = repo.head_name()?.expect("no detached head");
+            repo.commit(
+                name.as_bstr(),
+                "empty",
+                gix::hash::ObjectId::empty_tree(repo.object_hash()),
+                repo.try_find_reference(name.as_ref())?.map(|r| r.id()),
+            )?;
+            Ok(())
+        }
+        fn check_fetch_output(
+            repo: &gix::Repository,
+            out: gix::remote::fetch::Outcome,
+            expected_count: usize,
+        ) -> gix_testtools::Result {
+            for local_tracking_branch_name in out.ref_map.mappings.into_iter().filter_map(|m| m.local) {
+                let r = repo.find_reference(&local_tracking_branch_name)?;
+                r.id()
+                    .object()
+                    .expect("object should be present after fetching, triggering pack refreshes works");
+                repo.head_ref()?.unwrap().set_target_id(r.id(), "post fetch")?;
+            }
+            check_odb_accessability(repo, expected_count)?;
+            Ok(())
+        }
+        fn check_odb_accessability(repo: &gix::Repository, expected_count: usize) -> gix_testtools::Result {
+            let mut count_unique = 0;
+            // TODO: somehow there is a lot of duplication when receiving objects.
+            let mut seen = gix_hashtable::HashSet::default();
+            for id in repo.objects.iter()? {
+                let id = id?;
+                if !seen.insert(id) {
+                    continue;
+                }
+                let _obj = repo.find_object(id)?;
+                count_unique += 1;
+            }
+            assert_eq!(
+                count_unique, expected_count,
+                "Each round we receive exactly one commit, effectively"
+            );
+            Ok(())
+        }
+        for max_packs in 1..=3 {
+            let remote_dir = tempfile::tempdir()?;
+            let mut remote_repo = gix::init_bare(remote_dir.path())?;
+            {
+                let mut config = remote_repo.config_snapshot_mut();
+                config.set_value(&User::NAME, "author")?;
+                config.set_value(&User::EMAIL, "email@example.com")?;
+            }
+            create_empty_commit(&remote_repo)?;
+
+            let local_dir = tempfile::tempdir()?;
+            let (local_repo, _) = gix::clone::PrepareFetch::new(
+                remote_repo.path(),
+                local_dir.path(),
+                gix::create::Kind::Bare,
+                Default::default(),
+                gix::open::Options::isolated().object_store_slots(Slots::Given(max_packs)),
+            )?
+            .fetch_only(gix::progress::Discard, &IS_INTERRUPTED)?;
+
+            let remote = local_repo
+                .branch_remote(
+                    local_repo.head_ref()?.expect("branch available").name().shorten(),
+                    Fetch,
+                )
+                .expect("remote is configured after clone")?;
+            let minimum_slots = 5;
+            let slots = Slots::AsNeededByDiskState {
+                multiplier: 1.1,
+                minimum: minimum_slots,
+            };
+            let one_more_than_minimum = minimum_slots + 1;
+            for round_to_create_pack in 1..one_more_than_minimum {
+                let expected_object_count = round_to_create_pack + 1 + 1 /* first commit + tree */;
+                create_empty_commit(&remote_repo)?;
+                match remote
+                    .connect(Fetch)?
+                    .prepare_fetch(gix::progress::Discard, Default::default())?
+                    .receive(gix::progress::Discard, &IS_INTERRUPTED)
+                {
+                    Ok(out) => check_fetch_output(&local_repo, out, expected_object_count)?,
+                    Err(err) => {
+                        assert!(err
+                            .to_string()
+                            .starts_with("The slotmap turned out to be too small with "));
+                        // But opening a new repo will always be able to read all objects
+                        // as it dynamically sizes the otherwise static slotmap.
+                        let local_repo = gix::open_opts(
+                            local_repo.path(),
+                            gix::open::Options::isolated().object_store_slots(slots),
+                        )?;
+                        check_odb_accessability(&local_repo, expected_object_count)?;
+                    }
+                }
+            }
+        }
+        Ok(())
+    }
+
     #[test]
     #[cfg(feature = "blocking-network-client")]
     #[allow(clippy::result_large_err)]
@@ -175,7 +283,7 @@ mod blocking_and_async_io {
             ] {
                 let (mut client_repo, _tmp) = {
                     let client_repo = remote::repo("multi_round/client");
-                    let daemon = spawn_git_daemon_if_async(client_repo.work_dir().expect("non-bare"))?;
+                    let daemon = spawn_git_daemon_if_async(client_repo.workdir().expect("non-bare"))?;
                     let tmp = TempDir::new()?;
                     let repo = gix::prepare_clone_bare(
                         daemon.as_ref().map_or_else(
@@ -202,9 +310,9 @@ mod blocking_and_async_io {
                     )?;
                 }
                 let server_repo = remote::repo("multi_round/server");
-                let daemon = spawn_git_daemon_if_async(server_repo.work_dir().expect("non-bare"))?;
+                let daemon = spawn_git_daemon_if_async(server_repo.workdir().expect("non-bare"))?;
                 let remote = into_daemon_remote_if_async(
-                    client_repo.remote_at(server_repo.work_dir().expect("non-bare"))?,
+                    client_repo.remote_at(server_repo.workdir().expect("non-bare"))?,
                     daemon.as_ref(),
                     None,
                 );
@@ -365,7 +473,7 @@ mod blocking_and_async_io {
                         },
                     )?;
                     let daemon = spawn_git_daemon_if_async(
-                        repo.work_dir()
+                        repo.workdir()
                             .expect("non-bare")
                             .ancestors()
                             .nth(1)
@@ -457,10 +565,10 @@ mod blocking_and_async_io {
                     assert_eq!(negotiate.rounds.len(), 1);
                     assert_eq!(write_pack_bundle.index.data_hash, hex_to_id(expected_data_hash), );
                     assert_eq!(write_pack_bundle.index.num_objects, 3 + num_objects_offset, "{fetch_tags:?}");
-                    assert!(write_pack_bundle.data_path.as_deref().map_or(false, std::path::Path::is_file));
-                    assert!(write_pack_bundle.index_path.as_deref().map_or(false, std::path::Path::is_file));
+                    assert!(write_pack_bundle.data_path.as_deref().is_some_and(std::path::Path::is_file));
+                    assert!(write_pack_bundle.index_path.as_deref().is_some_and(std::path::Path::is_file));
                     assert_eq!(update_refs.edits.len(), expected_ref_edits, "{fetch_tags:?}");
-                    assert_eq!(write_pack_bundle.keep_path.as_deref().map_or(false, std::path::Path::is_file), update_refs.edits.is_empty(),".keep are kept if there was no edit to prevent `git gc` from clearing out the pack as it's not referred to necessarily");
+                    assert_eq!(write_pack_bundle.keep_path.as_deref().is_some_and(std::path::Path::is_file), update_refs.edits.is_empty(),".keep are kept if there was no edit to prevent `git gc` from clearing out the pack as it's not referred to necessarily");
                 },
                 _ => unreachable!("Naive negotiation sends the same have and wants, resulting in an empty pack (technically no change, but we don't detect it) - empty packs are fine")
             }
@@ -547,8 +655,8 @@ mod blocking_and_async_io {
                             write_pack_bundle.index.index_hash,
                             hex_to_id("d07c527cf14e524a8494ce6d5d08e28079f5c6ea")
                         );
-                        assert!(write_pack_bundle.data_path.map_or(false, |f| f.is_file()));
-                        assert!(write_pack_bundle.index_path.map_or(false, |f| f.is_file()));
+                        assert!(write_pack_bundle.data_path.is_some_and(|f| f.is_file()));
+                        assert!(write_pack_bundle.index_path.is_some_and(|f| f.is_file()));
                         assert_eq!(update_refs.edits.len(), 2);
 
                         let edit = &update_refs.edits[0];
@@ -578,7 +686,7 @@ mod blocking_and_async_io {
                         }
 
                         assert!(
-                            !write_pack_bundle.keep_path.map_or(false, |f| f.is_file()),
+                            !write_pack_bundle.keep_path.is_some_and(|f| f.is_file()),
                             ".keep files are deleted if there is one edit"
                         );
 
