@@ -1,11 +1,40 @@
 use gix_testtools::tempfile;
 
+use crate::util::named_subrepo_opts;
+
+mod object_database_impl {
+    use gix_object::{Exists, Find, FindHeader};
+
+    #[test]
+    fn empty_tree_is_always_present() -> crate::Result {
+        let repo = crate::named_subrepo_opts("make_basic_repo.sh", "unborn", gix::open::Options::isolated())?;
+        let empty_tree = gix::ObjectId::empty_tree(repo.object_hash());
+        assert!(repo.exists(&empty_tree));
+        assert_eq!(
+            repo.try_header(&empty_tree)?.expect("tree present"),
+            gix_object::Header {
+                kind: gix_object::Kind::Tree,
+                size: 0
+            }
+        );
+        let mut buf = repo.empty_reusable_buffer();
+        buf.push(42);
+        assert_eq!(
+            repo.try_find(&empty_tree, &mut buf)?.expect("tree present").kind,
+            gix_object::Kind::Tree
+        );
+        assert_eq!(buf.len(), 0, "the data in the buffer matches the empty tree");
+        Ok(())
+    }
+}
+
 #[cfg(feature = "tree-editor")]
 mod edit_tree {
-    use crate::util::hex_to_id;
     use gix::bstr::{BStr, BString};
     use gix_object::tree::EntryKind;
 
+    use crate::util::hex_to_id;
+
     #[test]
     // Some part of the test validation the implementation for this exists, but it's needless nonetheless.
     #[allow(clippy::needless_borrows_for_generic_args)]
@@ -118,6 +147,20 @@ mod edit_tree {
         Ok(())
     }
 
+    #[test]
+    fn submodules_are_not_checked_for_existence() -> crate::Result {
+        let repo = crate::named_subrepo_opts("make_submodules.sh", "with-submodules", gix::open::Options::isolated())?
+            .with_object_memory();
+        let mut editor = repo.head_tree()?.edit()?;
+        let actual = editor.write()?;
+        assert_eq!(
+            actual,
+            repo.head_tree_id()?,
+            "Nothing changed, but it did validate the root tree that it would want to write"
+        );
+        Ok(())
+    }
+
     #[test]
     fn missing_objects_and_illformed_path_components_trigger_error() -> crate::Result {
         let (repo, _tmp) = crate::repo_rw("make_packed_and_loose.sh")?;
@@ -162,8 +205,10 @@ mod edit_tree {
     }
 
     mod utils {
-        use gix::bstr::{BStr, ByteSlice};
-        use gix::Repository;
+        use gix::{
+            bstr::{BStr, ByteSlice},
+            Repository,
+        };
         use gix_hash::ObjectId;
 
         fn display_tree_recursive(
@@ -206,11 +251,11 @@ mod edit_tree {
     use utils::display_tree;
 }
 mod write_object {
-    use crate::repository::object::empty_bare_repo;
+    use crate::repository::object::empty_bare_in_memory_repo;
 
     #[test]
     fn empty_tree() -> crate::Result {
-        let (_tmp, repo) = empty_bare_repo()?;
+        let repo = empty_bare_in_memory_repo()?;
         let oid = repo.write_object(gix::objs::TreeRef::empty())?;
         assert_eq!(
             oid,
@@ -219,12 +264,40 @@ mod write_object {
         );
         Ok(())
     }
+
+    #[test]
+    fn commit_with_invalid_author() -> crate::Result {
+        let repo = empty_bare_in_memory_repo()?;
+        let actor = gix::actor::Signature {
+            name: "1 < 0".into(),
+            email: Default::default(),
+            time: Default::default(),
+        };
+        let commit = gix::objs::Commit {
+            tree: gix::hash::ObjectId::empty_tree(repo.object_hash()),
+            author: actor.clone(),
+            committer: actor,
+            parents: Default::default(),
+            encoding: None,
+            message: Default::default(),
+            extra_headers: vec![],
+        };
+        assert_eq!(
+            repo.write_object(commit).unwrap_err().to_string(),
+            r"Signature name or email must not contain '<', '>' or \n",
+            "the actor is invalid so triggers an error when persisting it"
+        );
+        Ok(())
+    }
 }
 
 mod write_blob {
     use std::io::{Seek, SeekFrom};
 
-    use crate::{repository::object::empty_bare_repo, util::hex_to_id};
+    use crate::{
+        repository::object::{empty_bare_in_memory_repo, empty_bare_repo},
+        util::hex_to_id,
+    };
 
     #[test]
     fn from_slice() -> crate::Result {
@@ -252,7 +325,7 @@ mod write_blob {
 
     #[test]
     fn from_stream() -> crate::Result {
-        let (_tmp, repo) = empty_bare_repo()?;
+        let repo = empty_bare_in_memory_repo()?;
         let mut cursor = std::io::Cursor::new(b"hello world");
         let mut seek_cursor = cursor.clone();
         let mut repo = repo.without_freelist();
@@ -467,10 +540,9 @@ mod tag {
 }
 
 mod commit_as {
+    use gix_date::parse::TimeBuf;
     use gix_testtools::tempfile;
 
-    use crate::util::restricted_and_git;
-
     #[test]
     fn specify_committer_and_author() -> crate::Result {
         let tmp = tempfile::tempdir()?;
@@ -478,24 +550,24 @@ mod commit_as {
             &tmp,
             gix::create::Kind::WithWorktree,
             Default::default(),
-            restricted_and_git(),
+            gix::open::Options::isolated(),
         )?
         .to_thread_local();
         let empty_tree = repo.empty_tree();
         let committer = gix::actor::Signature {
             name: "c".into(),
             email: "c@example.com".into(),
-            time: gix::date::Time::new(1, 1800),
+            time: gix_date::parse_header("1 +0030").unwrap(),
         };
         let author = gix::actor::Signature {
             name: "a".into(),
             email: "a@example.com".into(),
-            time: gix::date::Time::new(3, 3600),
+            time: gix_date::parse_header("3 +0100").unwrap(),
         };
 
         let commit_id = repo.commit_as(
-            &committer,
-            &author,
+            committer.to_ref(&mut TimeBuf::default()),
+            author.to_ref(&mut TimeBuf::default()),
             "HEAD",
             "initial",
             empty_tree.id,
@@ -503,8 +575,9 @@ mod commit_as {
         )?;
         let commit = commit_id.object()?.into_commit();
 
-        assert_eq!(commit.committer()?, committer.to_ref());
-        assert_eq!(commit.author()?, author.to_ref());
+        let mut buf = TimeBuf::default();
+        assert_eq!(commit.committer()?, committer.to_ref(&mut buf));
+        assert_eq!(commit.author()?, author.to_ref(&mut buf));
         Ok(())
     }
 }
@@ -641,6 +714,10 @@ mod commit {
     }
 }
 
+fn empty_bare_in_memory_repo() -> crate::Result<gix::Repository> {
+    Ok(named_subrepo_opts("make_basic_repo.sh", "bare.git", gix::open::Options::isolated())?.with_object_memory())
+}
+
 fn empty_bare_repo() -> crate::Result<(tempfile::TempDir, gix::Repository)> {
     let tmp = tempfile::tempdir()?;
     let repo = gix::ThreadSafeRepository::init_opts(
