@@ -7,20 +7,21 @@ use std::{
     },
 };
 
-use crate::shared::pretty::prepare_and_run;
 use anyhow::{anyhow, Context, Result};
 use clap::{CommandFactory, Parser};
 use gitoxide_core as core;
 use gitoxide_core::{pack::verify, repository::PathsOrPatterns};
 use gix::bstr::{io::BufReadExt, BString};
 
-use crate::plumbing::options::merge;
-use crate::plumbing::{
-    options::{
-        attributes, commit, commitgraph, config, credential, exclude, free, fsck, index, mailmap, odb, revision, tree,
-        Args, Subcommands,
+use crate::{
+    plumbing::{
+        options::{
+            attributes, commit, commitgraph, config, credential, exclude, free, fsck, index, mailmap, merge, odb,
+            revision, tag, tree, Args, Subcommands,
+        },
+        show_progress,
     },
-    show_progress,
+    shared::pretty::prepare_and_run,
 };
 
 #[cfg(feature = "gitoxide-core-async-client")]
@@ -117,6 +118,16 @@ pub fn main() -> Result<()> {
                     .append_config(config.iter(), gix::config::Source::Cli)
                     .context("Unable to parse command-line configuration")?;
             }
+            {
+                let mut config_mut = repo.config_snapshot_mut();
+                // Enable precious file parsing unless the user made a choice.
+                if config_mut
+                    .boolean(gix::config::tree::Gitoxide::PARSE_PRECIOUS)
+                    .is_none()
+                {
+                    config_mut.set_raw_value(&gix::config::tree::Gitoxide::PARSE_PRECIOUS, "true")?;
+                }
+            }
             Ok(repo)
         }
     };
@@ -146,6 +157,15 @@ pub fn main() -> Result<()> {
     }
 
     match cmd {
+        Subcommands::Env => prepare_and_run(
+            "env",
+            trace,
+            verbose,
+            progress,
+            progress_keep_open,
+            None,
+            move |_progress, out, _err| core::env(out, format),
+        ),
         Subcommands::Merge(merge::Platform { cmd }) => match cmd {
             merge::SubCommands::File {
                 resolve_with,
@@ -164,23 +184,83 @@ pub fn main() -> Result<()> {
                         repository(Mode::Lenient)?,
                         out,
                         format,
-                        resolve_with.map(|c| match c {
-                            merge::ResolveWith::Union => {
-                                gix::merge::blob::builtin_driver::text::Conflict::ResolveWithUnion
-                            }
-                            merge::ResolveWith::Ours => {
-                                gix::merge::blob::builtin_driver::text::Conflict::ResolveWithOurs
-                            }
-                            merge::ResolveWith::Theirs => {
-                                gix::merge::blob::builtin_driver::text::Conflict::ResolveWithTheirs
-                            }
-                        }),
+                        resolve_with.map(Into::into),
                         base,
                         ours,
                         theirs,
                     )
                 },
             ),
+            merge::SubCommands::Tree {
+                opts:
+                    merge::SharedOptions {
+                        in_memory,
+                        file_favor,
+                        tree_favor,
+                        debug,
+                    },
+                ours,
+                base,
+                theirs,
+            } => prepare_and_run(
+                "merge-tree",
+                trace,
+                verbose,
+                progress,
+                progress_keep_open,
+                None,
+                move |_progress, out, err| {
+                    core::repository::merge::tree(
+                        repository(Mode::Lenient)?,
+                        out,
+                        err,
+                        base,
+                        ours,
+                        theirs,
+                        core::repository::merge::tree::Options {
+                            format,
+                            file_favor: file_favor.map(Into::into),
+                            in_memory,
+                            tree_favor: tree_favor.map(Into::into),
+                            debug,
+                        },
+                    )
+                },
+            ),
+            merge::SubCommands::Commit {
+                opts:
+                    merge::SharedOptions {
+                        in_memory,
+                        file_favor,
+                        tree_favor,
+                        debug,
+                    },
+                ours,
+                theirs,
+            } => prepare_and_run(
+                "merge-commit",
+                trace,
+                verbose,
+                progress,
+                progress_keep_open,
+                None,
+                move |_progress, out, err| {
+                    core::repository::merge::commit(
+                        repository(Mode::Lenient)?,
+                        out,
+                        err,
+                        ours,
+                        theirs,
+                        core::repository::merge::tree::Options {
+                            format,
+                            file_favor: file_favor.map(Into::into),
+                            tree_favor: tree_favor.map(Into::into),
+                            in_memory,
+                            debug,
+                        },
+                    )
+                },
+            ),
         },
         Subcommands::MergeBase(crate::plumbing::options::merge_base::Command { first, others }) => prepare_and_run(
             "merge-base",
@@ -208,7 +288,30 @@ pub fn main() -> Result<()> {
                     core::repository::diff::tree(repository(Mode::Lenient)?, out, old_treeish, new_treeish)
                 },
             ),
+            crate::plumbing::options::diff::SubCommands::File {
+                old_revspec,
+                new_revspec,
+            } => prepare_and_run(
+                "diff-file",
+                trace,
+                verbose,
+                progress,
+                progress_keep_open,
+                None,
+                move |_progress, out, _err| {
+                    core::repository::diff::file(repository(Mode::Lenient)?, out, old_revspec, new_revspec)
+                },
+            ),
         },
+        Subcommands::Log(crate::plumbing::options::log::Platform { pathspec }) => prepare_and_run(
+            "log",
+            trace,
+            verbose,
+            progress,
+            progress_keep_open,
+            None,
+            move |_progress, out, _err| core::repository::log::log(repository(Mode::Lenient)?, out, pathspec),
+        ),
         Subcommands::Worktree(crate::plumbing::options::worktree::Platform { cmd }) => match cmd {
             crate::plumbing::options::worktree::SubCommands::List => prepare_and_run(
                 "worktree-list",
@@ -440,7 +543,7 @@ pub fn main() -> Result<()> {
             )
         }
         Subcommands::CommitGraph(cmd) => match cmd {
-            commitgraph::Subcommands::List { spec } => prepare_and_run(
+            commitgraph::Subcommands::List { long_hashes, spec } => prepare_and_run(
                 "commitgraph-list",
                 trace,
                 auto_verbose,
@@ -448,7 +551,7 @@ pub fn main() -> Result<()> {
                 progress_keep_open,
                 None,
                 move |_progress, out, _err| {
-                    core::repository::commitgraph::list(repository(Mode::Lenient)?, spec, out, format)
+                    core::repository::commitgraph::list(repository(Mode::Lenient)?, spec, out, long_hashes, format)
                 },
             )
             .map(|_| ()),
@@ -1045,7 +1148,12 @@ pub fn main() -> Result<()> {
             },
         ),
         Subcommands::Revision(cmd) => match cmd {
-            revision::Subcommands::List { spec, svg, limit } => prepare_and_run(
+            revision::Subcommands::List {
+                spec,
+                svg,
+                limit,
+                long_hashes,
+            } => prepare_and_run(
                 "revision-list",
                 trace,
                 auto_verbose,
@@ -1061,6 +1169,7 @@ pub fn main() -> Result<()> {
                             limit,
                             spec,
                             format,
+                            long_hashes,
                             text: svg.map_or(core::repository::revision::list::Format::Text, |path| {
                                 core::repository::revision::list::Format::Svg { path }
                             }),
@@ -1195,6 +1304,17 @@ pub fn main() -> Result<()> {
                 },
             ),
         },
+        Subcommands::Tag(platform) => match platform.cmds {
+            Some(tag::Subcommands::List) | None => prepare_and_run(
+                "tag-list",
+                trace,
+                auto_verbose,
+                progress,
+                progress_keep_open,
+                None,
+                move |_progress, out, _err| core::repository::tag::list(repository(Mode::Lenient)?, out),
+            ),
+        },
         Subcommands::Tree(cmd) => match cmd {
             tree::Subcommands::Entries {
                 treeish,
@@ -1464,6 +1584,37 @@ pub fn main() -> Result<()> {
                 },
             ),
         },
+        Subcommands::Blame {
+            statistics,
+            file,
+            ranges,
+            since,
+        } => prepare_and_run(
+            "blame",
+            trace,
+            verbose,
+            progress,
+            progress_keep_open,
+            None,
+            move |_progress, out, err| {
+                let repo = repository(Mode::Lenient)?;
+                let diff_algorithm = repo.diff_algorithm()?;
+
+                core::repository::blame::blame_file(
+                    repo,
+                    &file,
+                    gix::blame::Options {
+                        diff_algorithm,
+                        range: gix::blame::BlameRanges::from_ranges(ranges),
+                        since,
+                        rewrites: Some(gix::diff::Rewrites::default()),
+                        debug_track_path: false,
+                    },
+                    out,
+                    statistics.then_some(err),
+                )
+            },
+        ),
         Subcommands::Completions { shell, out_dir } => {
             let mut app = Args::command();
 
