@@ -4,6 +4,8 @@ use clap_complete::Shell;
 use gitoxide_core as core;
 use gix::bstr::BString;
 
+use crate::shared::{AsRange, AsTime};
+
 #[derive(Debug, clap::Parser)]
 #[clap(name = "gix", about = "The git underworld", version = option_env!("GIX_VERSION"))]
 #[clap(subcommand_required = true)]
@@ -20,10 +22,10 @@ pub struct Args {
     #[clap(long, short = 'c', value_parser = crate::shared::AsBString)]
     pub config: Vec<BString>,
 
-    #[clap(long, short = 't')]
     /// The amount of threads to use for some operations.
     ///
     /// If unset, or the value is 0, there is no limit and all logical cores can be used.
+    #[clap(long, short = 't')]
     pub threads: Option<usize>,
 
     /// Display verbose messages and progress information
@@ -39,7 +41,7 @@ pub struct Args {
     #[clap(long, conflicts_with("verbose"))]
     pub no_verbose: bool,
 
-    /// Bring up a terminal user interface displaying progress visually
+    /// Bring up a terminal user interface displaying progress visually.
     #[cfg(feature = "prodash-render-tui")]
     #[clap(long, conflicts_with("verbose"))]
     pub progress: bool,
@@ -78,12 +80,13 @@ pub struct Args {
 
 #[derive(Debug, clap::Subcommand)]
 pub enum Subcommands {
-    /// Subcommands for creating worktree archives
+    /// Subcommands for creating worktree archives.
     #[cfg(feature = "gitoxide-core-tools-archive")]
     Archive(archive::Platform),
+    /// Remove untracked files from the working tree.
     #[cfg(feature = "gitoxide-core-tools-clean")]
     Clean(clean::Command),
-    /// Subcommands for interacting with commit-graph files
+    /// Subcommands for interacting with commit-graph files.
     #[clap(subcommand)]
     CommitGraph(commitgraph::Subcommands),
     /// Interact with the object database.
@@ -97,6 +100,9 @@ pub enum Subcommands {
     /// Interact with commit objects.
     #[clap(subcommand)]
     Commit(commit::Subcommands),
+    /// Interact with tag objects.
+    #[clap(visible_alias = "tags")]
+    Tag(tag::Platform),
     /// Verify the integrity of the entire repository
     Verify {
         #[clap(flatten)]
@@ -108,9 +114,10 @@ pub enum Subcommands {
     /// A program just like `git credential`.
     #[clap(subcommand)]
     Credential(credential::Subcommands),
-    /// Fetch data from remotes and store it in the repository
+    /// Fetch data from remotes and store it in the repository.
     #[cfg(feature = "gitoxide-core-blocking-client")]
     Fetch(fetch::Platform),
+    /// Clone a repository into a new directory.
     #[cfg(feature = "gitoxide-core-blocking-client")]
     Clone(clone::Platform),
     /// Interact with the mailmap.
@@ -125,6 +132,7 @@ pub enum Subcommands {
     /// Interact with the exclude files like .gitignore.
     #[clap(subcommand)]
     Exclude(exclude::Subcommands),
+    /// Interact with a worktree index like .git/index.
     #[clap(subcommand)]
     Index(index::Subcommands),
     /// Interact with submodules.
@@ -135,7 +143,9 @@ pub enum Subcommands {
         /// The object to print to stdout.
         revspec: String,
     },
+    /// Check for changes in the repository, treating this as an error.
     IsClean,
+    /// Check for changes in the repository, treating their absence as an error.
     IsChanged,
     /// Show which git configuration values are used or planned.
     ConfigTree,
@@ -145,11 +155,28 @@ pub enum Subcommands {
     Corpus(corpus::Platform),
     MergeBase(merge_base::Command),
     Merge(merge::Platform),
+    /// Print paths relevant to the Git installation.
+    Env,
     Diff(diff::Platform),
+    Log(log::Platform),
     Worktree(worktree::Platform),
-    /// Subcommands that need no git repository to run.
+    /// Subcommands that need no Git repository to run.
     #[clap(subcommand)]
     Free(free::Subcommands),
+    /// Blame lines in a file.
+    Blame {
+        /// Print additional statistics to help understanding performance.
+        #[clap(long, short = 's')]
+        statistics: bool,
+        /// The file to create the blame information for.
+        file: std::ffi::OsString,
+        /// Only blame lines in the given 1-based inclusive range '<start>,<end>', e.g. '20,40'.
+        #[clap(short='L', value_parser=AsRange, action=clap::ArgAction::Append)]
+        ranges: Vec<std::ops::RangeInclusive<u32>>,
+        /// Don't consider commits before the given date.
+        #[clap(long,  value_parser=AsTime, value_name = "DATE")]
+        since: Option<gix::date::Time>,
+    },
     /// Generate shell completions to stdout or a directory.
     #[clap(visible_alias = "generate-completions", visible_alias = "shell-completions")]
     Completions {
@@ -210,9 +237,10 @@ pub mod archive {
 }
 
 pub mod status {
-    use crate::shared::{CheckPathSpec, ParseRenameFraction};
     use gix::bstr::BString;
 
+    use crate::shared::{CheckPathSpec, ParseRenameFraction};
+
     #[derive(Default, Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord, clap::ValueEnum)]
     pub enum Submodules {
         /// display all information about submodules, including ref changes, modifications and untracked files.
@@ -250,7 +278,7 @@ pub mod status {
     }
 
     #[derive(Debug, clap::Parser)]
-    #[command(about = "compute repository status similar to `git status`")]
+    #[command(about = "Compute repository status similar to `git status`")]
     pub struct Platform {
         /// The way status data is displayed.
         #[clap(long, short = 'f')]
@@ -297,7 +325,7 @@ pub mod worktree {
 
     #[derive(Debug, clap::Subcommand)]
     pub enum SubCommands {
-        /// List all worktrees, along with some accompanying information
+        /// List all worktrees, along with some accompanying information.
         List,
     }
 }
@@ -307,7 +335,7 @@ pub mod corpus {
     use std::path::PathBuf;
 
     #[derive(Debug, clap::Parser)]
-    #[command(about = "run algorithms on a corpus of git repositories and store their results for later analysis")]
+    #[command(about = "Run algorithms on a corpus of git repositories and store their results for later analysis")]
     pub struct Platform {
         /// The path to the database to read and write depending on the sub-command.
         #[arg(long, default_value = "corpus.db")]
@@ -357,8 +385,70 @@ pub mod merge {
         Theirs,
     }
 
+    impl From<ResolveWith> for gix::merge::blob::builtin_driver::text::Conflict {
+        fn from(value: ResolveWith) -> Self {
+            match value {
+                ResolveWith::Union => gix::merge::blob::builtin_driver::text::Conflict::ResolveWithUnion,
+                ResolveWith::Ours => gix::merge::blob::builtin_driver::text::Conflict::ResolveWithOurs,
+                ResolveWith::Theirs => gix::merge::blob::builtin_driver::text::Conflict::ResolveWithTheirs,
+            }
+        }
+    }
+
+    #[derive(Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord, clap::ValueEnum)]
+    pub enum FileFavor {
+        /// Use only ours in case of conflict.
+        Ours,
+        /// Use only theirs in case of conflict.
+        Theirs,
+    }
+
+    #[derive(Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord, clap::ValueEnum)]
+    pub enum TreeFavor {
+        /// Use only the previous tree entry in case of conflict.
+        Ancestor,
+        /// Use only ours tree entry in case of conflict.
+        Ours,
+    }
+
+    impl From<FileFavor> for gix::merge::tree::FileFavor {
+        fn from(value: FileFavor) -> Self {
+            match value {
+                FileFavor::Ours => gix::merge::tree::FileFavor::Ours,
+                FileFavor::Theirs => gix::merge::tree::FileFavor::Theirs,
+            }
+        }
+    }
+
+    impl From<TreeFavor> for gix::merge::tree::TreeFavor {
+        fn from(value: TreeFavor) -> Self {
+            match value {
+                TreeFavor::Ancestor => gix::merge::tree::TreeFavor::Ancestor,
+                TreeFavor::Ours => gix::merge::tree::TreeFavor::Ours,
+            }
+        }
+    }
+
     #[derive(Debug, clap::Parser)]
-    #[command(about = "perform merges of various kinds")]
+    pub struct SharedOptions {
+        /// Keep all objects to be written in memory to avoid any disk IO.
+        ///
+        /// Note that the resulting tree won't be available or inspectable.
+        #[clap(long, short = 'm')]
+        pub in_memory: bool,
+        /// Decide how to resolve content conflicts in files. If unset, write conflict markers and fail.
+        #[clap(long, short = 'f')]
+        pub file_favor: Option<FileFavor>,
+        /// Decide how to resolve conflicts in trees, i.e. modification/deletion. If unset, try to preserve both states and fail.
+        #[clap(long, short = 't')]
+        pub tree_favor: Option<TreeFavor>,
+        /// Print additional information about conflicts for debugging.
+        #[clap(long, short = 'd')]
+        pub debug: bool,
+    }
+
+    #[derive(Debug, clap::Parser)]
+    #[command(about = "Perform merges of various kinds")]
     pub struct Platform {
         #[clap(subcommand)]
         pub cmd: SubCommands,
@@ -379,7 +469,35 @@ pub mod merge {
             #[clap(value_name = "BASE", value_parser = crate::shared::AsBString)]
             base: BString,
             /// A path or revspec to their file.
+            #[clap(value_name = "THEIRS", value_parser = crate::shared::AsBString)]
+            theirs: BString,
+        },
+
+        /// Merge a tree by specifying ours, base and theirs, writing it to the object database.
+        Tree {
+            #[clap(flatten)]
+            opts: SharedOptions,
+
+            /// A revspec to our treeish.
             #[clap(value_name = "OURS", value_parser = crate::shared::AsBString)]
+            ours: BString,
+            /// A revspec to the base as treeish for both ours and theirs.
+            #[clap(value_name = "BASE", value_parser = crate::shared::AsBString)]
+            base: BString,
+            /// A revspec to their treeish.
+            #[clap(value_name = "THEIRS", value_parser = crate::shared::AsBString)]
+            theirs: BString,
+        },
+        /// Merge a commits by specifying ours, and theirs, writing the tree to the object database.
+        Commit {
+            #[clap(flatten)]
+            opts: SharedOptions,
+
+            /// A revspec to our committish.
+            #[clap(value_name = "OURS", value_parser = crate::shared::AsBString)]
+            ours: BString,
+            /// A revspec to their committish.
+            #[clap(value_name = "THEIRS", value_parser = crate::shared::AsBString)]
             theirs: BString,
         },
     }
@@ -388,7 +506,7 @@ pub mod merge {
 pub mod diff {
     use gix::bstr::BString;
 
-    /// Print all changes between two objects
+    /// Print all changes between two objects.
     #[derive(Debug, clap::Parser)]
     pub struct Platform {
         #[clap(subcommand)]
@@ -406,13 +524,34 @@ pub mod diff {
             #[clap(value_parser = crate::shared::AsBString)]
             new_treeish: BString,
         },
+        /// Diff two versions of a file.
+        File {
+            /// A rev-spec representing the 'before' or old state of the file, like '@~100:file'
+            #[clap(value_parser = crate::shared::AsBString)]
+            old_revspec: BString,
+            /// A rev-spec representing the 'after' or new state of the file, like ':file'
+            #[clap(value_parser = crate::shared::AsBString)]
+            new_revspec: BString,
+        },
+    }
+}
+
+pub mod log {
+    use gix::bstr::BString;
+
+    /// List all commits in a repository, optionally limited to those that change a given path.
+    #[derive(Debug, clap::Parser)]
+    pub struct Platform {
+        /// The git path specification to show a log for.
+        #[clap(value_parser = crate::shared::AsBString)]
+        pub pathspec: Option<BString>,
     }
 }
 
 pub mod config {
     use gix::bstr::BString;
 
-    /// Print all entries in a configuration file or access other sub-commands
+    /// Print all entries in a configuration file or access other sub-commands.
     #[derive(Debug, clap::Parser)]
     #[clap(subcommand_required(false))]
     pub struct Platform {
@@ -469,7 +608,7 @@ pub mod fetch {
         #[clap(long, help_heading = Some("SHALLOW"), conflicts_with_all = ["shallow_since", "shallow_exclude", "deepen", "unshallow"])]
         pub depth: Option<NonZeroU32>,
 
-        /// Extend the current shallow boundary by the given amount of commits, with 0 meaning no change.
+        /// Extend the current shallow boundary by the given number of commits, with 0 meaning no change.
         #[clap(long, help_heading = Some("SHALLOW"), value_name = "DEPTH", conflicts_with_all = ["depth", "shallow_since", "shallow_exclude", "unshallow"])]
         pub deepen: Option<u32>,
 
@@ -628,9 +767,10 @@ pub mod mailmap {
 
 #[cfg(feature = "gitoxide-core-tools-clean")]
 pub mod clean {
-    use crate::shared::CheckPathSpec;
     use gix::bstr::BString;
 
+    use crate::shared::CheckPathSpec;
+
     #[derive(Default, Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord, clap::ValueEnum)]
     pub enum FindRepository {
         All,
@@ -791,6 +931,20 @@ pub mod commit {
     }
 }
 
+pub mod tag {
+    #[derive(Debug, clap::Parser)]
+    pub struct Platform {
+        #[clap(subcommand)]
+        pub cmds: Option<Subcommands>,
+    }
+
+    #[derive(Debug, clap::Subcommand)]
+    pub enum Subcommands {
+        /// List all tags.
+        List,
+    }
+}
+
 pub mod credential {
     #[derive(Debug, clap::Subcommand)]
     pub enum Subcommands {
@@ -810,7 +964,7 @@ pub mod credential {
 pub mod commitgraph {
     #[derive(Debug, clap::Subcommand)]
     pub enum Subcommands {
-        /// Verify the integrity of a commit graph file
+        /// Verify the integrity of a commit graph file.
         Verify {
             /// output statistical information about the graph.
             #[clap(long, short = 's')]
@@ -818,6 +972,9 @@ pub mod commitgraph {
         },
         /// List all entries in the commit-graph file as reachable by starting from `HEAD`.
         List {
+            /// Display long hashes, instead of expensively shortened versions for best performance.
+            #[clap(long, short = 'l')]
+            long_hashes: bool,
             /// The rev-spec to list reachable commits from.
             #[clap(default_value = "@")]
             spec: std::ffi::OsString,
@@ -843,7 +1000,7 @@ pub mod revision {
             Git,
             /// The version that would be checked out into the worktree, including filters.
             Worktree,
-            /// The version that would be diffed (Worktree + Text-Conversion)
+            /// The version that would be diffed (Worktree + Text-Conversion).
             Diff,
             /// The version that would be diffed if there is a text-conversion, or the one stored in Git otherwise.
             DiffOrGit,
@@ -856,8 +1013,11 @@ pub mod revision {
         /// List all commits reachable from the given rev-spec.
         #[clap(visible_alias = "l")]
         List {
-            /// How many commits to list at most.
+            /// Display long hashes, instead of expensively shortened versions for best performance.
             #[clap(long, short = 'l')]
+            long_hashes: bool,
+            /// How many commits to list at most.
+            #[clap(long)]
             limit: Option<usize>,
             /// Write the graph as SVG file to the given path.
             #[clap(long, short = 's')]
@@ -900,15 +1060,16 @@ pub mod revision {
 }
 
 pub mod attributes {
-    use crate::shared::CheckPathSpec;
     use gix::bstr::BString;
 
+    use crate::shared::CheckPathSpec;
+
     #[derive(Debug, clap::Subcommand)]
     pub enum Subcommands {
-        /// Run `git check-attr`  and `git check-ignore` on all files of the index or all files passed via stdin and validate that
-        /// we get the same outcome when computing attributes.
+        /// Run `git check-attr` and `git check-ignore` on all files of the index or all files
+        /// passed via stdin and validate that we get the same outcome when computing attributes.
         ValidateBaseline {
-            /// Print various statistics to stderr
+            /// Print various statistics to stderr.
             #[clap(long, short = 's')]
             statistics: bool,
             /// Don't validated excludes as obtaining them with `check-ignore` can be very slow.
@@ -917,10 +1078,10 @@ pub mod attributes {
         },
         /// List all attributes of the given path-specs and display the result similar to `git check-attr`.
         Query {
-            /// Print various statistics to stderr
+            /// Print various statistics to stderr.
             #[clap(long, short = 's')]
             statistics: bool,
-            /// The git path specifications to list attributes for, or unset to read from stdin one per line.
+            /// The Git path specifications to list attributes for, or unset to read from stdin one per line.
             #[clap(value_parser = CheckPathSpec)]
             pathspec: Vec<BString>,
         },
@@ -930,14 +1091,15 @@ pub mod attributes {
 pub mod exclude {
     use std::ffi::OsString;
 
-    use crate::shared::CheckPathSpec;
     use gix::bstr::BString;
 
+    use crate::shared::CheckPathSpec;
+
     #[derive(Debug, clap::Subcommand)]
     pub enum Subcommands {
         /// Check if path-specs are excluded and print the result similar to `git check-ignore`.
         Query {
-            /// Print various statistics to stderr
+            /// Print various statistics to stderr.
             #[clap(long, short = 's')]
             statistics: bool,
             /// Show actual ignore patterns instead of un-excluding an entry.
@@ -960,9 +1122,10 @@ pub mod exclude {
 pub mod index {
     use std::path::PathBuf;
 
-    use crate::shared::CheckPathSpec;
     use gix::bstr::BString;
 
+    use crate::shared::CheckPathSpec;
+
     pub mod entries {
         #[derive(Default, Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord, clap::ValueEnum)]
         pub enum Format {
@@ -976,7 +1139,7 @@ pub mod index {
 
     #[derive(Debug, clap::Subcommand)]
     pub enum Subcommands {
-        /// Print all entries to standard output
+        /// Print all entries to standard output.
         Entries {
             /// How to output index entries.
             #[clap(long, short = 'f', default_value = "simple", value_enum)]
@@ -992,7 +1155,7 @@ pub mod index {
             /// Display submodule entries as well if their repository exists.
             #[clap(long, short = 'r')]
             recurse_submodules: bool,
-            /// Print various statistics to stderr
+            /// Print various statistics to stderr.
             #[clap(long, short = 's')]
             statistics: bool,
             /// The git path specifications to match entries to print.
@@ -1006,8 +1169,10 @@ pub mod index {
             #[clap(long, short = 'f')]
             force: bool,
             /// Path to the index file to be written.
-            /// If none is given it will be kept in memory only as a way to measure performance. One day we will probably write the index
-            /// back by default, but that requires us to write more of the index to work.
+            ///
+            /// If none is given it will be kept in memory only as a way to measure performance.
+            /// One day we will probably write the index back by default, but that requires us to
+            /// write more of the index to work.
             #[clap(long, short = 'i')]
             index_output_path: Option<PathBuf>,
             /// Don't write the trailing hash for a performance gain.
@@ -1028,7 +1193,7 @@ pub mod submodule {
 
     #[derive(Debug, clap::Subcommand)]
     pub enum Subcommands {
-        /// Print all direct submodules to standard output
+        /// Print all direct submodules to standard output.
         List {
             /// Set the suffix to append if the repository is dirty (not counting untracked files).
             #[clap(short = 'd', long)]
