@@ -1,5 +1,7 @@
-use std::fmt::{Display, Formatter};
-use std::io::StdoutLock;
+use std::{
+    fmt::{Display, Formatter},
+    io::StdoutLock,
+};
 
 #[derive(Clone)]
 enum Usage {
@@ -29,7 +31,7 @@ impl Display for Usage {
             }
             InUse(deviation) => {
                 if !deviation.is_empty() {
-                    write!(f, "❗️❗️❗️{deviation}")?;
+                    write!(f, "❗️{deviation}")?;
                 }
             }
         }
@@ -62,6 +64,10 @@ struct Record {
 }
 
 static GIT_CONFIG: &[Record] = &[
+    Record {
+        config: "attr.tree",
+        usage: Planned("Decides where to read git attributes from - this will affect APIs")
+    },
     Record {
         config: "core.symlinks",
         usage: Planned("Needed to handle checkouts faithfully")
@@ -411,12 +417,12 @@ static GIT_CONFIG: &[Record] = &[
         usage: Planned("Required for big monorepos, and typically used in conjunction with sparse indices")
     },
     Record {
-        config: "merge.renameLimit",
-        usage: Planned("The same as 'diff.renameLimit'")
+        config: "merge.directoryRenames",
+        usage: NotPlanned("On demand")
     },
     Record {
-        config: "merge.renames",
-        usage: Planned("The same as 'diff.renames'")
+        config: "merge.verbosity",
+        usage: NotApplicable("Only useful for Git CLI")
     },
     Record {
         config: "status.renameLimit",
@@ -431,7 +437,7 @@ static GIT_CONFIG: &[Record] = &[
         usage: Planned("Currently we are likely to expose passwords in errors or in other places, and it's better to by default not do that")
     },
     Record {
-        config: "diff.*.cachetextconv",
+        config: "diff.*.cacheTextConv",
         usage: NotPlanned("It seems to slow to do that, and persisting results to save a relatively cheap computation doesn't seem right")
     },
 ];
