@@ -59,6 +59,7 @@ impl Drop for GitDaemon {
 }
 
 static SCRIPT_IDENTITY: Lazy<Mutex<BTreeMap<PathBuf, u32>>> = Lazy::new(|| Mutex::new(BTreeMap::new()));
+
 static EXCLUDE_LUT: Lazy<Mutex<Option<gix_worktree::Stack>>> = Lazy::new(|| {
     let cache = (|| {
         let (repo_path, _) = gix_discover::upwards(Path::new(".")).ok()?;
@@ -66,15 +67,25 @@ static EXCLUDE_LUT: Lazy<Mutex<Option<gix_worktree::Stack>>> = Lazy::new(|| {
         let work_tree = work_tree?.canonicalize().ok()?;
 
         let mut buf = Vec::with_capacity(512);
-        let case = gix_fs::Capabilities::probe(&work_tree)
-            .ignore_case
-            .then_some(gix_worktree::ignore::glob::pattern::Case::Fold)
-            .unwrap_or_default();
+        let case = if gix_fs::Capabilities::probe(&work_tree).ignore_case {
+            gix_worktree::ignore::glob::pattern::Case::Fold
+        } else {
+            Default::default()
+        };
         let state = gix_worktree::stack::State::IgnoreStack(gix_worktree::stack::state::Ignore::new(
             Default::default(),
-            gix_worktree::ignore::Search::from_git_dir(&gix_dir, None, &mut buf).ok()?,
+            gix_worktree::ignore::Search::from_git_dir(
+                &gix_dir,
+                None,
+                &mut buf,
+                gix_worktree::stack::state::ignore::ParseIgnore {
+                    support_precious: false,
+                },
+            )
+            .ok()?,
             None,
             gix_worktree::stack::state::ignore::Source::WorktreeThenIdMappingIfNotSkipped,
+            Default::default(),
         ));
         Some(gix_worktree::Stack::new(
             work_tree,
@@ -86,8 +97,31 @@ static EXCLUDE_LUT: Lazy<Mutex<Option<gix_worktree::Stack>>> = Lazy::new(|| {
     })();
     Mutex::new(cache)
 });
+
+#[cfg(windows)]
+const GIT_PROGRAM: &str = "git.exe";
+#[cfg(not(windows))]
+const GIT_PROGRAM: &str = "git";
+
+static GIT_CORE_DIR: Lazy<PathBuf> = Lazy::new(|| {
+    let output = std::process::Command::new(GIT_PROGRAM)
+        .arg("--exec-path")
+        .output()
+        .expect("can execute `git --exec-path`");
+
+    assert!(output.status.success(), "`git --exec-path` failed");
+
+    output
+        .stdout
+        .strip_suffix(b"\n")
+        .expect("`git --exec-path` output to be well-formed")
+        .to_os_str()
+        .expect("no invalid UTF-8 in `--exec-path` except as OS allows")
+        .into()
+});
+
 /// The major, minor and patch level of the git version on the system.
-pub static GIT_VERSION: Lazy<(u8, u8, u8)> = Lazy::new(|| parse_gix_version().expect("git version to be parsable"));
+pub static GIT_VERSION: Lazy<(u8, u8, u8)> = Lazy::new(|| parse_git_version().expect("git version to be parsable"));
 
 /// Define how [`scripted_fixture_writable_with_args()`] uses produces the writable copy.
 pub enum Creation {
@@ -116,10 +150,8 @@ pub fn should_skip_as_git_version_is_smaller_than(major: u8, minor: u8, patch: u
     *GIT_VERSION < (major, minor, patch)
 }
 
-fn parse_gix_version() -> Result<(u8, u8, u8)> {
-    let gix_program = cfg!(windows).then(|| "git.exe").unwrap_or("git");
-    let output = std::process::Command::new(gix_program).arg("--version").output()?;
-
+fn parse_git_version() -> Result<(u8, u8, u8)> {
+    let output = std::process::Command::new(GIT_PROGRAM).arg("--version").output()?;
     git_version_from_bytes(&output.stdout)
 }
 
@@ -173,7 +205,7 @@ impl Drop for AutoRevertToPreviousCWD {
 
 /// Run `git` in `working_dir` with all provided `args`.
 pub fn run_git(working_dir: &Path, args: &[&str]) -> std::io::Result<std::process::ExitStatus> {
-    std::process::Command::new("git")
+    std::process::Command::new(GIT_PROGRAM)
         .current_dir(working_dir)
         .args(args)
         .status()
@@ -181,17 +213,6 @@ pub fn run_git(working_dir: &Path, args: &[&str]) -> std::io::Result<std::proces
 
 /// Spawn a git daemon process to host all repository at or below `working_dir`.
 pub fn spawn_git_daemon(working_dir: impl AsRef<Path>) -> std::io::Result<GitDaemon> {
-    static EXEC_PATH: Lazy<PathBuf> = Lazy::new(|| {
-        let path = std::process::Command::new("git")
-            .arg("--exec-path")
-            .stderr(std::process::Stdio::null())
-            .output()
-            .expect("can execute `git --exec-path`")
-            .stdout;
-        String::from_utf8(path.trim().into())
-            .expect("no invalid UTF8 in exec-path")
-            .into()
-    });
     let mut ports: Vec<_> = (9419u16..9419 + 100).collect();
     fastrand::shuffle(&mut ports);
     let addr_at = |port| std::net::SocketAddr::from(([127, 0, 0, 1], port));
@@ -200,14 +221,15 @@ pub fn spawn_git_daemon(working_dir: impl AsRef<Path>) -> std::io::Result<GitDae
         listener.local_addr().expect("listener address is available").port()
     };
 
-    let child = std::process::Command::new(EXEC_PATH.join(if cfg!(windows) { "git-daemon.exe" } else { "git-daemon" }))
-        .current_dir(working_dir)
-        .args(["--verbose", "--base-path=.", "--export-all", "--user-path"])
-        .arg(format!("--port={free_port}"))
-        .spawn()?;
+    let child =
+        std::process::Command::new(GIT_CORE_DIR.join(if cfg!(windows) { "git-daemon.exe" } else { "git-daemon" }))
+            .current_dir(working_dir)
+            .args(["--verbose", "--base-path=.", "--export-all", "--user-path"])
+            .arg(format!("--port={free_port}"))
+            .spawn()?;
 
     let server_addr = addr_at(free_port);
-    for time in gix_lock::backoff::Exponential::default_with_random() {
+    for time in gix_lock::backoff::Quadratic::default_with_random() {
         std::thread::sleep(time);
         if std::net::TcpStream::connect(server_addr).is_ok() {
             break;
@@ -390,7 +412,7 @@ pub fn copy_recursively_into_existing_dir(src_dir: impl AsRef<Path>, dst_dir: im
             ..Default::default()
         },
     )
-    .map_err(|err| std::io::Error::new(std::io::ErrorKind::Other, err))?;
+    .map_err(std::io::Error::other)?;
     Ok(())
 }
 
@@ -461,8 +483,9 @@ fn scripted_fixture_read_only_with_args_inner(
                 let mut crc_digest = crc_value.digest();
                 crc_digest.update(&std::fs::read(&script_path).unwrap_or_else(|err| {
                     panic!(
-                        "file {script_path:?} in CWD {:?} could not be read: {err}",
-                        env::current_dir().expect("valid cwd"),
+                        "file {script_path} in CWD '{cwd}' could not be read: {err}",
+                        cwd = env::current_dir().expect("valid cwd").display(),
+                        script_path = script_path.display(),
                     )
                 }));
                 for arg in &args {
@@ -509,15 +532,25 @@ fn scripted_fixture_read_only_with_args_inner(
         |d| (true, d.to_owned()),
     );
 
-    let _marker = gix_lock::Marker::acquire_to_hold_resource(
-        script_basename,
-        gix_lock::acquire::Fail::AfterDurationWithBackoff(Duration::from_secs(6 * 60)),
-        None,
-    )?;
+    // We may that destination_dir is already unique (i.e. temp-dir) - thus there is no need for a lock,
+    // and we can execute scripts in parallel.
+    let _marker = destination_dir
+        .is_none()
+        .then(|| {
+            gix_lock::Marker::acquire_to_hold_resource(
+                script_basename,
+                gix_lock::acquire::Fail::AfterDurationWithBackoff(Duration::from_secs(6 * 60)),
+                None,
+            )
+        })
+        .transpose()?;
     let failure_marker = script_result_directory.join("_invalid_state_due_to_script_failure_");
     if force_run || !script_result_directory.is_dir() || failure_marker.is_file() {
         if failure_marker.is_file() {
-            std::fs::remove_dir_all(&script_result_directory).map_err(|err| format!("Failed to remove '{script_result_directory:?}', please try to do that by hand. Original error: {err}"))?;
+            std::fs::remove_dir_all(&script_result_directory).map_err(|err| {
+                format!("Failed to remove '{script_result_directory}', please try to do that by hand. Original error: {err}",
+                        script_result_directory = script_result_directory.display())
+            })?;
         }
         std::fs::create_dir_all(&script_result_directory)?;
         let script_identity_for_archive = match args_in_hash {
@@ -540,7 +573,11 @@ fn scripted_fixture_read_only_with_args_inner(
             Err(err) => {
                 if err.kind() != std::io::ErrorKind::NotFound {
                     eprintln!("failed to extract '{}': {}", archive_file_path.display(), err);
-                    std::fs::remove_dir_all(&script_result_directory).map_err(|err| format!("Failed to remove '{script_result_directory:?}', please try to do that by hand. Original error: {err}"))?;
+                    std::fs::remove_dir_all(&script_result_directory)
+                        .map_err(|err| {
+                            format!("Failed to remove '{script_result_directory}', please try to do that by hand. Original error: {err}",
+                                    script_result_directory = script_result_directory.display())
+                        })?;
                     std::fs::create_dir_all(&script_result_directory)?;
                 } else if !is_excluded(&archive_file_path) {
                     eprintln!(
@@ -554,22 +591,19 @@ fn scripted_fixture_read_only_with_args_inner(
                 let output = match configure_command(&mut cmd, &args, &script_result_directory).output() {
                     Ok(out) => out,
                     Err(err)
-                        if err.kind() == std::io::ErrorKind::PermissionDenied || err.raw_os_error() == Some(193) /* windows */ =>
-                    {
-                        cmd = std::process::Command::new("bash");
-                        configure_command(cmd.arg(script_absolute_path), &args, &script_result_directory).output()?
-                    }
+                    if err.kind() == std::io::ErrorKind::PermissionDenied || err.raw_os_error() == Some(193) /* windows */ =>
+                        {
+                            cmd = std::process::Command::new(bash_program());
+                            configure_command(cmd.arg(script_absolute_path), &args, &script_result_directory).output()?
+                        }
                     Err(err) => return Err(err.into()),
                 };
                 if !output.status.success() {
                     write_failure_marker(&failure_marker);
+                    eprintln!("stdout: {}", output.stdout.as_bstr());
+                    eprintln!("stderr: {}", output.stderr.as_bstr());
+                    return Err(format!("fixture script of {cmd:?} failed").into());
                 }
-                assert!(
-                    output.status.success(),
-                    "fixture script of {cmd:?} failed: stdout: {}\nstderr: {}",
-                    output.stdout.as_bstr(),
-                    output.stderr.as_bstr()
-                );
                 create_archive_if_we_should(
                     &script_result_directory,
                     &archive_file_path,
@@ -632,6 +666,62 @@ fn configure_command<'a, I: IntoIterator<Item = S>, S: AsRef<OsStr>>(
         .env("GIT_CONFIG_VALUE_3", "always")
 }
 
+/// Get the path attempted as a `bash` interpreter, for fixture scripts having no `#!` we can use.
+///
+/// This is rarely called on Unix-like systems, provided that fixture scripts have usable shebang
+/// (`#!`) lines and are marked executable. However, Windows does not recognize `#!` when executing
+/// a file. If all fixture scripts that cannot be directly executed are `bash` scripts or can be
+/// treated as such, fixture generation still works on Windows, as long as this function manages to
+/// find or guess a suitable `bash` interpreter.
+///
+/// ### Search order
+///
+/// This function is used internally. It is public to facilitate diagnostic use. The following
+/// details are subject to change without warning, and changes are treated as non-breaking.
+///
+/// The `bash.exe` found in a path search is not always suitable on Windows. This is mainly because
+/// `bash.exe` in `System32`, which is associated with WSL, would often be found first. But even
+/// where that is not the case, the best `bash.exe` to use to run fixture scripts to set up Git
+/// repositories for testing is usually one associated with Git for Windows, even if some other
+/// `bash.exe` would be found in a path search. Currently, the search order we use is as follows:
+///
+/// 1. The shim `bash.exe`, which sets environment variables when run and is, on some systems,
+///    needed to find the POSIX utilities that scripts need (or correct versions of them).
+///
+/// 2. The non-shim `bash.exe`, which is sometimes available even when the shim is not available.
+///    This is mainly because the Git for Windows SDK does not come with a `bash.exe` shim.
+///
+/// 3. As a fallback, the simple name `bash.exe`, which triggers a path search when run.
+///
+/// On non-Windows systems, the simple name `bash` is used, which triggers a path search when run.
+pub fn bash_program() -> &'static Path {
+    // TODO(deps): Unify with `gix_path::env::shell()` by having both call a more general function
+    //             in `gix-path`. See https://github.com/GitoxideLabs/gitoxide/issues/1886.
+    static GIT_BASH: Lazy<PathBuf> = Lazy::new(|| {
+        if cfg!(windows) {
+            GIT_CORE_DIR
+                .ancestors()
+                .nth(3)
+                .map(OsStr::new)
+                .iter()
+                .flat_map(|prefix| {
+                    // Go down to places `bash.exe` usually is. Keep using `/` separators, not `\`.
+                    ["/bin/bash.exe", "/usr/bin/bash.exe"].into_iter().map(|suffix| {
+                        let mut raw_path = (*prefix).to_owned();
+                        raw_path.push(suffix);
+                        raw_path
+                    })
+                })
+                .map(PathBuf::from)
+                .find(|bash| bash.is_file())
+                .unwrap_or_else(|| "bash.exe".into())
+        } else {
+            "bash".into()
+        }
+    });
+    GIT_BASH.as_ref()
+}
+
 fn write_failure_marker(failure_marker: &Path) {
     std::fs::write(failure_marker, []).ok();
 }
@@ -645,13 +735,12 @@ fn should_skip_all_archive_creation() -> bool {
 }
 
 fn is_lfs_pointer_file(path: &Path) -> bool {
-    const PREFIX: &[u8] = b"version https://gix-lfs";
+    const PREFIX: &[u8] = b"version https://git-lfs";
     let mut buf = [0_u8; PREFIX.len()];
     std::fs::OpenOptions::new()
         .read(true)
         .open(path)
-        .and_then(|mut f| f.read_exact(&mut buf))
-        .map_or(false, |_| buf.starts_with(PREFIX))
+        .is_ok_and(|mut f| f.read_exact(&mut buf).is_ok_and(|_| buf.starts_with(PREFIX)))
 }
 
 /// The `script_identity` will be baked into the soon to be created `archive` as it identifies the script
@@ -738,7 +827,10 @@ fn populate_meta_dir(destination_dir: &Path, script_identity: u32) -> std::io::R
     )?;
     std::fs::write(
         meta_dir.join(META_GIT_VERSION),
-        std::process::Command::new("git").arg("--version").output()?.stdout,
+        std::process::Command::new(GIT_PROGRAM)
+            .arg("--version")
+            .output()?
+            .stdout,
     )?;
     Ok(meta_dir)
 }
@@ -755,13 +847,10 @@ fn extract_archive(
         #[cfg_attr(feature = "xz", allow(unused_mut))]
         let mut input_archive = std::fs::File::open(archive)?;
         if env::var_os("GIX_TEST_IGNORE_ARCHIVES").is_some() {
-            return Err(std::io::Error::new(
-                std::io::ErrorKind::Other,
-                format!(
-                    "Ignoring archive at '{}' as GIX_TEST_IGNORE_ARCHIVES is set.",
-                    archive.display()
-                ),
-            ));
+            return Err(std::io::Error::other(format!(
+                "Ignoring archive at '{}' as GIX_TEST_IGNORE_ARCHIVES is set.",
+                archive.display()
+            )));
         }
         #[cfg(feature = "xz")]
         {
@@ -793,17 +882,12 @@ fn extract_archive(
                 None
             }
         })
-        .ok_or_else(|| {
-            std::io::Error::new(
-                std::io::ErrorKind::Other,
-                "BUG: Could not find meta directory in our own archive",
-            )
-        })
+        .ok_or_else(|| std::io::Error::other("BUG: Could not find meta directory in our own archive"))
         .map_err(|err| {
-            std::io::Error::new(
-                std::io::ErrorKind::Other,
-                format!("Could not extract archive at '{archive:?}': {err}"),
-            )
+            std::io::Error::other(format!(
+                "Could not extract archive at '{archive}': {err}",
+                archive = archive.display()
+            ))
         })?;
     if archive_identity != required_script_identity {
         eprintln!(
@@ -882,6 +966,43 @@ impl Drop for Env<'_> {
     }
 }
 
+/// Check data structure size, comparing strictly on 64-bit targets.
+///
+/// - On 32-bit targets, checks if `actual_size` is at most `expected_64_bit_size`.
+/// - On 64-bit targets, checks if `actual_size` is exactly `expected_64_bit_size`.
+///
+/// This is for assertions about the size of data structures, when the goal is to keep them from
+/// growing too large even across breaking changes. Such assertions must always fail when data
+/// structures grow larger than they have ever been, for which `<=` is enough. But it also helps to
+/// know when they have shrunk unexpectedly. They may shrink, other changes may rely on the smaller
+/// size for acceptable performance, and then they may grow again to their earlier size.
+///
+/// The problem with `==` is that data structures are often smaller on 32-bit targets. This could
+/// be addressed by asserting separate exact 64-bit and 32-bit sizes. But sizes may also differ
+/// across 32-bit targets, due to ABI and layout/packing details. That can happen across 64-bit
+/// targets too, but it seems less common.
+///
+/// For those reasons, this function does a `==` on 64-bit targets, but a `<=` on 32-bit targets.
+pub fn size_ok(actual_size: usize, expected_64_bit_size: usize) -> bool {
+    #[cfg(target_pointer_width = "64")]
+    return actual_size == expected_64_bit_size;
+    #[cfg(target_pointer_width = "32")]
+    return actual_size <= expected_64_bit_size;
+}
+
+/// Get the umask in a way that is safe, but may be too slow for use outside of tests.
+#[cfg(unix)]
+pub fn umask() -> u32 {
+    let output = std::process::Command::new("/bin/sh")
+        .args(["-c", "umask"])
+        .output()
+        .expect("can execute `sh -c umask`");
+    assert!(output.status.success(), "`sh -c umask` failed");
+    assert_eq!(output.stderr.as_bstr(), "", "`sh -c umask` unexpected message");
+    let text = output.stdout.to_str().expect("valid Unicode").trim();
+    u32::from_str_radix(text, 8).expect("parses as octal number")
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -927,7 +1048,7 @@ mod tests {
         let temp = tempfile::TempDir::new().expect("can create temp dir");
         populate_ad_hoc_config_files(temp.path());
 
-        let mut cmd = std::process::Command::new("git");
+        let mut cmd = std::process::Command::new(GIT_PROGRAM);
         cmd.env("GIT_CONFIG_SYSTEM", SCOPE_ENV_VALUE);
         cmd.env("GIT_CONFIG_GLOBAL", SCOPE_ENV_VALUE);
         configure_command(&mut cmd, ["config", "-l", "--show-origin"], temp.path());
@@ -944,4 +1065,71 @@ mod tests {
         assert_eq!(lines, Vec::<&str>::new(), "should be no config variables from files");
         assert_eq!(status, 0, "reading the config should succeed");
     }
+
+    #[test]
+    #[cfg(windows)]
+    fn bash_program_ok_for_platform() {
+        let path = bash_program();
+        assert!(path.is_absolute());
+
+        let for_version = std::process::Command::new(path)
+            .arg("--version")
+            .output()
+            .expect("can pass it `--version`");
+        assert!(for_version.status.success(), "passing `--version` succeeds");
+        let version_line = for_version
+            .stdout
+            .lines()
+            .nth(0)
+            .expect("`--version` output has first line");
+        assert!(
+            version_line.ends_with(b"-pc-msys)"), // On Windows, "-pc-linux-gnu)" would be WSL.
+            "it is an MSYS bash (such as Git Bash)"
+        );
+
+        let for_uname_os = std::process::Command::new(path)
+            .args(["-c", "uname -o"])
+            .output()
+            .expect("can tell it to run `uname -o`");
+        assert!(for_uname_os.status.success(), "telling it to run `uname -o` succeeds");
+        assert_eq!(
+            for_uname_os.stdout.trim_end(),
+            b"Msys",
+            "it runs commands in an MSYS environment"
+        );
+    }
+
+    #[test]
+    #[cfg(not(windows))]
+    fn bash_program_ok_for_platform() {
+        assert_eq!(bash_program(), Path::new("bash"));
+    }
+
+    #[test]
+    fn bash_program_unix_path() {
+        let path = bash_program()
+            .to_str()
+            .expect("This test depends on the bash path being valid Unicode");
+        assert!(
+            !path.contains('\\'),
+            "The path to bash should have no backslashes, barring very unusual environments"
+        );
+    }
+
+    fn is_rooted_relative(path: impl AsRef<Path>) -> bool {
+        let p = path.as_ref();
+        p.is_relative() && p.has_root()
+    }
+
+    #[test]
+    #[cfg(windows)]
+    fn unix_style_absolute_is_rooted_relative() {
+        assert!(is_rooted_relative("/bin/bash"), "can detect paths like /bin/bash");
+    }
+
+    #[test]
+    fn bash_program_absolute_or_unrooted() {
+        let bash = bash_program();
+        assert!(!is_rooted_relative(bash), "{bash:?}");
+    }
 }
