@@ -7,21 +7,6 @@ RED="$(tput setaf 1 2>/dev/null || echo -n '')"
 OFFSET=( )
 STEP="  "
 
-function with_program () {
-  local program="${1:?}"
-  hash "$program" &>/dev/null || {
-    function expect_run () {
-      echo 1>&2 "${WHITE} - skipped (missing program)"
-    }
-    function expect_run_sh () {
-      echo 1>&2 "${WHITE} - skipped (missing program)"
-    }
-    function expect_run_sh_no_pipefail () {
-      echo 1>&2 "${WHITE} - skipped (missing program)"
-    }
-  }
-}
-
 function on_ci () {
   [ -n "${CI-}" ] || {
     function expect_run () {
